data.update <- function(save = FALSE) {

  InputFile <- c("crutem3gl", "crutem3nh", "crutem3sh", "hadcrut3gl", "hadcrut3nh",
            "hadcrut3sh", "amon.us.long.data", "cetml1659on.dat", "PDO.latest",
             "naodjfmindex.asc", "GLB.Ts", "NH.Ts", "SH.Ts", "GLB.Ts+dSST", "NH.Ts+dSST",
	     "SH.Ts+dSST")
  OutputFile <- c("crutem3gl", "crutem3nh", "crutem3sh", "hadcrut3gl", "hadcrut3nh",
            "hadcrut3sh", "AMO", "CET", "PDO", "NAO_DJFM_Hurrell", "giss_ghcn_gl",  
	    "giss_ghcn_nh", "giss_ghcn_sh", "giss_ghcn_sst_gl", 
	    "giss_ghcn_sst_nh", "giss_ghcn_sst_sh")
  path <- c(rep("http://www.cru.uea.ac.uk/cru/data/temperature/", 6), 
	    "http://www.cdc.noaa.gov/data/correlation/",
            "http://hadobs.metoffice.com/hadcet/", 
            "http://jisao.washington.edu/pdo/",
            "http://www.cgd.ucar.edu/cas/jhurrell/Data/",
            rep("http://data.giss.nasa.gov/gistemp/tabledata/", 6))
  lw <- c(rep(14,6),13,14,13,2,rep(20,6)) # number of columns in input text files
  skip <- c(rep(0,6),1,7,31,0,rep(8,3),rep(9,3)) # number of first rows to skip
  naval <- c(rep(0,6),-99.99,-99.9,0,-99.9,rep(0,6)) # missing value substitutes

  NF <- length(InputFile)
  for(i in 1:NF) {
    if ((i < 7) || (i > 10)) filei <- paste(path[i], InputFile[i], ".txt", sep="")
    else filei <- paste(path[i], InputFile[i], sep="")
    cat("(", i, ") Data set: ", InputFile[i], " (", filei,") \n", sep="")

    what <- list()
    for(j in 1:lw[i]) 
      if (i > 10) what[[j]] <- character(0) # GISS
      else what[[j]] <- double(0)
    if (i == 9) what[[1]] <- character(0) # PDO
    wcon <- url(filei)
    start <- scan(wcon, fill=TRUE, skip=skip[i], n=1, quiet=TRUE)
    N <- as.numeric(format(Sys.time(), "%Y")) - start + 1 # number of available years

    if (i == 10) {N <- N - 1; P <- 1} # NAO DJFM
    else P <- 12 # number of months a year
    
    if (i < 7) x <- scan(wcon, what=what, fill=TRUE, quiet=TRUE) # CRU, HadCRUT
    if ((i > 6)&&(i <11)) x<-scan(wcon,what=what,fill=TRUE,skip=skip[i],nmax=N,quiet=TRUE)
    if (i > 10) { # GISS
      N = N - 1
      K = trunc(N/20)
      NMax = K + N
      x <- scan(wcon,what=what,fill=TRUE,skip=skip[i],nmax=NMax,quiet=TRUE)
#      cat("x[[2]] = ", x[[2]][],"\n",sep="")
    }
    close(wcon)

#    cat("Number of Lines = ",length(x[[1]]),"\n",sep="")
    data <- matrix(NA, N, P)
    if (i < 7) {
      odd = 2*seq(1,N)-1 # taking care of every second useless row
      years <- x[[1]][odd]
      for (j in 1:P) data[,j] <- x[[(j+1)]][odd]
    }
    if ((i > 6)&&(i < 11)) {
      years <- x[[1]]
      for (j in 1:P) data[,j] <- x[[j+1]]
      if (i == 9) { # PDO
	years <- unlist(strsplit(years,"*",fixed=TRUE))
	years[years==""] <- NA
	years <- as.numeric(na.omit(years))
      }
    }
    if (i > 10) {
#      cat("N = ",N,", K = ",K,", NMax = ",NMax,", P = ",P,"\n",sep="")
      mylist = seq(1,21) # taking care of a useless row every 20 years
      for (j in 2:K) mylist = c(mylist, seq((21*(j-1)+2),(21*j)))
      mylist = c(mylist, seq((21*K+2),NMax))
#      cat("mylist = ", mylist,"\n",sep="")
#      cat("myL = ", length(mylist), "\n", sep="")
      years <- x[[1]][mylist]
      for (j in 1:P) data[,j] <- as.numeric(x[[(j+1)]][mylist])/100
    }
#    cat("First Year = ", years[1], ", Last Year = ",years[N],"\n",sep="")
    Cdata <- matrix(t(data), ncol=1, byrow=TRUE) # format data in one column
    L <- length(Cdata)

    if (i != 10) {
      mvals <- 0 # number of missing months (values)
      while(TRUE) {
	if(is.na(Cdata[L-mvals])) mvals <- mvals + 1
	else if(Cdata[L-mvals] == naval[i]) mvals <- mvals + 1
               else break
      }
#      cat("L = ", L, ", mvals = ", mvals, "\n", sep="")
      Mdata <- as.vector(Cdata[1:(L-mvals)]) # monthly data
#      cat("Mdata = ", Mdata,"\n",sep="")
      L <- L - mvals
      fm <- P - mvals # the last available month (final month)
      NY <- trunc(L/P) # number of full years
      Adata <- apply(data[1:NY,], 1, mean) # annual means
      Mfile <- paste(OutputFile[i], "_1.", years[1], "_", fm, ".", years[N], sep="")
      Mdata <- ts(Mdata, start=as.numeric(years[1]), deltat=1/P)#create time series object
      assign(Mfile, Mdata, env = .GlobalEnv)
    }
    else {Adata <- as.vector(data); NY <- L;}

    Afile <- paste(OutputFile[i], "_", years[1], "_", years[NY], sep="")
    Adata <- ts(Adata, start=as.numeric(years[1])) # create time series object
    assign(Afile, Adata, env = .GlobalEnv)

    if (i != 10) cat("Downloaded", Mfile, "and", Afile, "\n")
    else cat("Downloaded", Afile, "\n")

    if(save) {
      if (i != 10) save(list=Mfile, file=paste(Mfile,".rda",sep=""))
      save(list=Afile, file=paste(Afile,".rda",sep=""))
      if (i != 10) cat("Saved", Mfile, "and", Afile, "\n")
      else cat("Saved", Afile, "\n")
    }
    cat("\n")
  }
}
