dfa.lse <- function(x, L = (3*x$order+9), M =
           round(x$scale[length(x$scale)]/4), verbose = TRUE, ffe = NULL, ...)
{
  if(class(x) != "ffe") stop(sQuote("x"), " must be of class ", sQuote("ffe"))
  if (is.null(ffe)) ffe <- deparse(substitute(x))
  if (M < L) stop(sQuote("M"), " must be larger than ", sQuote("L"))
  order <- x$order
  checkparam(L, DFALbound(order, M))
  N = round(x$scale[length(x$scale)])
  if (M > N) {
    M = N
    if (verbose) 
      cat("M was set equal to the maximum available scale, ", M, "\n")
  }
  checkparam(M, DFAMbound(L, N))
  Scale <- x$scale
  NS <- length(Scale)
  FF <- x$fluctuation
  LIndex = 1
  while(Scale[LIndex] < L) LIndex = LIndex + 1
  MIndex = LIndex
  while((Scale[MIndex] < M) & (MIndex < NS)) MIndex = MIndex + 1
  Range = seq(LIndex, MIndex)
  lScale = log(Scale)

  lFF = log(FF)
  BF = summary(lm(lFF[Range] ~ lScale[Range]))
  q = BF$coefficients[1]
  r = exp(q)
  H = BF$coefficients[2]
  stdq = BF$coefficients[3]
  stdH = BF$coefficients[4]
  method <- "Least Squares Estimate"
  call <- match.call()
  res <- tdhee(H = H, stdH = stdH, r = r, q=q, stdq = stdq, L = L,
               M = M, ffe = ffe, method = method, call = call)
  if(verbose) print(res)
  invisible(res)
}
