gfit.test <- function(H = 0.8, phi = 0.5, sd.fd.res = 1, sd.ar.res = 1, lfc = 0, 
          hfc = 2, s = 100, n = seq(400,2000,100), verbose = TRUE, 
          plot = TRUE)
{
  if(H <= 0 || H >= 1) stop(sQuote("H"), " must be in the interval (0,1)")
  if(abs(phi) >= 1) stop(sQuote("phi"), " must be in the interval (-1,1)")
  D <- H - 1/2
  SIGFD <- sd.fd.res
  PHI <- phi
  SIGAR <- sd.ar.res
  ln <- length(n)
  if (verbose) {
    cat("H =", H, ", SD of FD residuals =", sd.fd.res, "\n")
    cat("Phi =", phi, ", SD of AR(1) residuals =", sd.ar.res, "\n")
    cat("Number of time series lengths =", ln, "\n")
    cat("Number of samples for each time series lengths =", s, "\n")
    cat("\nTime series length:\n")
  }
  pvals <- array(0,c(ln,2,2))
  test <- c("Ljung-Box test","Spectral Density Function test")
  type <- c("FD process, AR(1) model","AR(1) process, FD Model")
  dimnames(pvals) <- list(ts.length = n, test = test, type = type)

  for(i in 1:ln) {
    lx <- n[i]
    if(verbose) cat(lx," ",sep="")
    ps.L = lfc # low-frequency cutoff
    ps.M = trunc(lx/hfc) # high-frequency cutoff
    for(j in 1:s) {
      x.fd <- fracdiff.sim(lx,d=D,sd=SIGFD)$series
      ps.fd <- ps.pgram(x.fd,verbose=FALSE)
      m.ar <- ps.ar1(ps.fd,verbose=FALSE)
      p.lb.ar <- pmt.test(x.fd, m=m.ar, type="Ljung-Box")$Bt$p.value
      p.sdf.ar <- sdf.test(ps.fd, m=m.ar, L=ps.L, M=ps.M, verbose=FALSE)$p
      pvals[i,1,1] <- pvals[i,1,1]+p.lb.ar
      pvals[i,2,1] <- pvals[i,2,1]+p.sdf.ar

      x.ar <- arima.sim(n = lx, list(ar = PHI), sd = SIGAR)
      ps.ar <- ps.pgram(x.ar, verbose=FALSE)
      m.fd <- ps.gspe(ps.ar, verbose=FALSE)
      p.lb.fd <- pmt.test(x.ar, m=m.fd, type="Ljung-Box")$Bt$p.value
      p.sdf.fd <- sdf.test(ps.ar, m=m.fd, L=ps.L, M=ps.M, verbose=FALSE)$p
      pvals[i,1,2] <- pvals[i,1,2]+p.lb.fd
      pvals[i,2,2] <- pvals[i,2,2]+p.sdf.fd
    }
  }
  cat("\n")
  p <- 1-pvals/s

  res <- structure(p, class = "Gtest")
  if(verbose) print(res)
  if(plot) plot(res)
  invisible(res)
}

