Orderbound <- function () { return(list(lower = 1, upper = 5)) }

DFALbound <- function (order,M) { return(list(lower = order+2, upper = M-2)) }

DFAMbound <- function (L,N) { return(list(lower = L+2, upper = N)) }

DFAOrderbound <- function () { return(list(lower = L+2, upper = N)) }

Lbound <- function (M) { return(list(lower = 0, upper = M-2)) }

Mbound <- function (L,N) { return(list(lower = L+2, upper = round((N-1)/2))) }

checkparam <- function (x,bound)
{
  if (x < bound$lower || x > bound$upper)
    stop(sQuote(deparse(substitute(x))), " must be between ", bound$lower,
         " and ", bound$upper)
}

check.ts <- function(x, name = deparse(substitute(x)), na.action = na.fail,
            demean = TRUE)
{
  if (!is.null(dim(x))) stop(sQuote(name), " must be a univariate time series")
  x <- na.action(x)
  if (any(is.na(x))) stop("NAs in ", sQuote(x))
  if (!is.numeric(x)) stop(sQuote(name), " must be numeric")
  if (demean) x <- x - mean(x)
  return(x)
}

check.taper <- function(dt = c("dpss","sine"), N, K, ...)
{
  v <- NULL
  if(!is.character(dt)) {
    { if(class(dt) == "sine.taper") {
        taper <- "sine"
        h <- dt
      }
      else if(class(dt) == "dpss.taper") {
        taper <- "dpss"
        h <- dt$eigenvectors
        v <- dt$eigenvalues
      }
      else {
        taper <- ""
        dt <- as.matrix(dt)
        if(!is.numeric(dt)) stop(sQuote("dt")," must be numeric")
        if(nrow(dt) != N)
          stop("row length of ", qQuote("dt"), " must be the same length as ",
               sQuote("x"))
        h <- dt
      }
    }
  }
  else {
    { if(dt == "sine") {
        taper <- "sine"
        dt <- sine.taper(n = N, K = K, ...)
        h <- dt
      }
      else if(dt == "dpss") {
        taper = "dpss"
        dt <- dpss.taper(n = N, K = K, ...)
        h <- dt$eigenvectors
        v <- dt$eigenvalues
      }
      else stop("unknown taper ", sQuote("dt"))
    }
  }
  K <- ncol(h)
  if(N != nrow(h))
    stop(sQuote("dt"), "must have the same length as ", sQuote("x"))
  invisible(list(h = h, v = v, K = K, taper = taper))
}

#adaptive multitaper from Percival and Walden's textbook, p. 361-370
a.mtm <- function(Smtk, N, v, NH, K)
{
  #initialize variables
  nh1 <- rep(1,NH)
  SmtOld <- rep(0,NH)

  # initial spectrum estimate, see Percival and Walden, p. 370
  sqrtv <- sqrt(v)
  Smt <- apply(Smtk, 1, mean)
  var <- mean(Smt)
  tol <- 0.001*var
  while (abs(mean(Smt-SmtOld)) > tol) {
    SmtOld <- Smt
    var <- mean(SmtOld)
    wt <- (SmtOld%*%t(sqrtv))/(SmtOld%*%t(v)+ nh1%*%t(1-v)*var) # Eq. (368a)*sqrt(v[k])
    wt[wt > 1] <- 1
    wt2 <- wt^2 # v[k]*b_k(f)^2
    Smt <- apply(wt2*Smtk, 1, sum)/apply(wt2, 1, sum) # Eq. (370a)
  }
  wt <- wt^2 # v[k]*b_k(f)^2
  #equivalent (chi-square) degrees of freedom
  edf <- 2*apply(wt, 1, sum)^2 / apply(wt^2, 1, sum) # Eq. (370b)
  invisible(list(Smt = Smt, edf = edf, wt = wt))
}
