hurst.conv <- function(H = 0.8, T = seq(270,910,by=90), s = 100, order = 3,
              lfc = 0, hfc=18, methods = c("dfa.lse", "pgram.gphe", "mtm.gphe",
              "pgram.gspe", "mtm.gspe"), verbose = TRUE, plot = TRUE, ...)
{
  methods <- match.arg(methods, several.ok = TRUE)

  N = length(T)
  if (verbose) {
    cat("H =", H, ", Time Series Length =", T, "\n")
    cat("Number of Time Series Lengths =", N, "\n")
    cat("Number of Samples for Each Time Series Length =", s, "\n")
  }
  lms <- length(methods)
  d = H - 0.5
  bH = array(0,c(lms,N))
  dimnames(bH) <- list(methods = methods, n = T)

  for (i in 1:N) {

    dfa.L = hfc # high-frequency cutoff
    if (lfc > 0) dfa.M = round(T[i]/lfc)
    else dfa.M = T[i]
    ps.L = lfc # low-frequency cutoff
    ps.M = trunc(T[i]/hfc) # high-frequency cutoff

    #GPHE_asdH = pi/sqrt(24*(ps.M-ps.L))
    #GSPE_asdH = 1/sqrt(4*(ps.M-ps.L))
    if(verbose) {
      cat("i = ", i, "of", N, ", T =", T[i], "\n")
      #cat("An asymptotic standard deviation of H: estimated by GPHE =",
      #round(GPHE_asdH,3), ", estimated by GSPE =", round(GSPE_asdH,3),"\n")
    }
    for (j in 1:s) {
      if (d >= 0.5) {
        X = fracdiff.sim(n=T[i], d=(d-1), mu=0)$series
        X = X - mean(X)
        Y = cumsum(X)
      }
      else Y = fracdiff.sim(n=T[i], d=d, mu=0)$series
      Y = Y - mean(Y)
      for(k in 1:lms) {
        Hest <- switch(methods[k],
          dfa.lse = dfa.lse(dfa.ffe(Y, order = order, verbose = FALSE,...),
                            L = dfa.L, M = dfa.M, verbose = FALSE, ...)$H,
          pgram.gphe = ps.gphe(ps.pgram(Y, verbose = FALSE, ...), 
                            L = ps.L, M = ps.M, verbose = FALSE, ...)$H,
          pgram.gspe = ps.gspe(ps.pgram(Y, verbose = FALSE, ...), 
                            L = ps.L, M = ps.M, verbose = FALSE, ...)$H,
          mtm.gphe = ps.gphe(ps.mtm(Y, verbose = FALSE, ...), 
                            L = ps.L, M = ps.M, verbose = FALSE, ...)$H,
          mtm.gspe = ps.gspe(ps.mtm(Y, verbose = FALSE, ...),
                            L = ps.L, M = ps.M, verbose = FALSE, ...)$H
        )
        bH[k,i] <- bH[k,i] + Hest - H
      }
    }
  }

  bH = bH/s

  res <- structure(
            list(H=H, bH=bH, T=T, s=s, order=order, lfc=lfc, hfc=hfc),
            class = "Hconv")

  if(plot) plot(res, ...)
  invisible(res)
}
