hurst.test <- function(H = seq(0.5,1.1,by=0.1), T = 540, s = 100, order = 3,
              lfc = 0, hfc = 18, methods = c("dfa.lse", "pgram.gphe", "mtm.gphe",
              "pgram.gspe", "mtm.gspe"), verbose = TRUE, plot = TRUE, ...)
{
  methods <- match.arg(methods, several.ok = TRUE)
#   asdH = array(0, 5)
#   asdH[seq(1,5,by=2)]=NA
#   asdH[2] = pi/sqrt(24*(ps.M-ps.L))
#   asdH[4] = 1/sqrt(4*(ps.M-ps.L))
  N = length(H)
  d = H - 0.5
  lms = length(methods)
  bH = array(0, c(lms, N))
  sdH = array(0, c(lms, N))
  dimnames(bH) = list(methods = methods, H = H)
  dimnames(sdH) = list(methods = methods, H = H)
  dfa.L = hfc # high-frequency cutoff
  if (lfc > 0) dfa.M = round(T/lfc)
  else dfa.M = T
  ps.L = lfc
  ps.M = trunc(T/hfc)

  dfa.L = hfc # high-frequency cutoff
  if (lfc > 0) dfa.M = round(T/lfc)
  else dfa.M = T 
  ps.L = lfc # low-frequency cutoff
  ps.M = trunc(T/hfc)

  if(verbose) {
    cat("H =", H, ", Time Series Length =", T, "\n")
    cat("Number of the Hurst exponents tested =", N, "\n")
    cat("Number of Samples for Each Time Series Length =", s, "\n")
    #cat("An asymptotic standard deviation of the estimated H =",
    #round(asdH,3),
    #"\n")
  }

  # Estimation of (b,d) for s number of samples
  for (j in 1:s) {
    cat("j = ", j, "of", s, "\n")
    for (i in 1:N) {
      if (d[i] >= 0.5) {
        X = fracdiff.sim(n=T, d=(d[i]-1), mu=0)$series
        X = X - mean(X)
        Y = cumsum(X)
      }
      else Y = fracdiff.sim(n=T, d=d[i], mu=0)$series
      if(all(Y == 0)) {
        print(d[i])
      }
      Y = Y - mean(Y)
      for(k in 1:lms) {
        Hest <- switch(methods[k],
          dfa.lse = dfa.lse(dfa.ffe(Y, order = order, verbose = FALSE,...),
                            L = dfa.L, M = dfa.M, verbose = FALSE, ...)$H,
          pgram.gphe = ps.gphe(ps.pgram(Y, verbose = FALSE, ...), 
                            L = ps.L, M = ps.M, verbose = FALSE, ...)$H,
          pgram.gspe = ps.gspe(ps.pgram(Y, verbose = FALSE, ...), 
                            L = ps.L, M = ps.M, verbose = FALSE, ...)$H,
          mtm.gphe = ps.gphe(ps.mtm(Y, verbose = FALSE, ...), 
                            L = ps.L, M = ps.M, verbose = FALSE, ...)$H,
          mtm.gspe = ps.gspe(ps.mtm(Y, verbose = FALSE, ...),
                            L = ps.L, M = ps.M, verbose = FALSE, ...)$H
        )
        bH[k,i] = bH[k,i] + Hest - H[i]
        sdH[k,i] = sdH[k,i] + (Hest - H[i])^2
      }
    }
  }
  bH = bH/s
  sdH = sqrt((sdH-s*bH^2)/(s-1))

  res <- structure(
            list(H = H, bH = bH, sdH = sdH, T = T, 
              s = s, order=order, lfc=lfc, hfc=hfc),
            class = "Htest")
  if (plot) plot(res, ...)
  invisible(res)
}
