ps.ar1 <- function(x, method = c("mle", "lse"), verbose = TRUE, pse = NULL, ...)
{
  if(class(x) != "pse") stop(sQuote("x"), " must be of class ", sQuote("pse"))
  if(x$method == "Multitaper")
    warning("ps.ar1 is not theoretically justified for ", sQuote("pse"), 
            " objects of method ", sQuote("Multitaper"))
  f <- x$frequency; s <- x$spectrum
  if (is.null(pse)) pse <- deparse(substitute(x))
  method <- match.arg(method)
  N = 2*length(f)+1
  df = 1/N
  V = 2*sum(s)*df
  SD = sqrt(V)

  if(method == "mle") {
    G <- function(x) V*(1-x^2)/(1-2*x*cos(2*pi*f)+x^2)
    R <- function(y) mean(log(G(y)) + s/G(y)) # see e.g. J.Beran's book, page 116

    out = optimize(R, c(0, 1))
    Phi = out$minimum
    dPhi = NA
  }

  if(method == "lse") {
    NL = nls(s ~ V*(1-phi^2)/(1-2*phi*cos(2*pi*f)+phi^2), 
             start=list(phi=0.5))
    Phi = coef(summary(NL))[1]
    dPhi = coef(summary(NL))[2]
  }

  PS_AR1 = V*(1-Phi^2)/(1-2*Phi*cos(2*pi*f)+Phi^2)

  method <- "Spectral Domain Lag One Autocorrelation Estimation"
  res <- sdare(phi = Phi, sdphi = dPhi, method = method, pse = pse,
               psa = PS_AR1, call = match.call())

  if(verbose) print(res)
  invisible(res)
}
