#pse constructor
pse <- function(frequency, spectrum, spectrum.ci = NA, cl = NA, ntaper = NA,
       series = "", taper = "", weight = "", method = "", call = match.call())
{
  structure(
    list(frequency = frequency, spectrum = spectrum, spectrum.ci =
         spectrum.ci, cl = cl, ntaper = ntaper, series = series, taper =
         taper, weight = weight, method = method, call = match.call()),
    class = "pse")
}

#pse print
print.pse <- function(x, ...)
{
  NH <- length(x$frequency)
  method <- x$method
  cat("Method = ", method, ", Total Number of Fourier Frequencies = ", NH, "\n", sep="")
  if (method == "Multitaper") {
    cat("Number of tapers = ", x$ntaper, sep="")
    if (is.character(x$taper)) cat(", Taper type = ", x$taper, ", Weighting type = ", x$weight, "\n", sep="")
    else cat(", Taper type = User defined, Weighting type = Uniform \n", sep="")
  }
  invisible(x)
}

#pse plot
plot.pse <- function(x, ar = NULL, h = NULL, plot.ci = TRUE, type = "o", xlim =
            NULL, ylim = NULL, main = NULL, xlab = NULL, ylab = NULL, xaxt="s", ...)
{
  f <- x$frequency; s <- x$spectrum; K <- x$ntaper; series <- x$series
  taper <- x$taper; method <- x$method

  are <- if(is.null(ar)) FALSE else TRUE
  he <- if(is.null(h)) FALSE else TRUE

  if (are && class(ar) != "sdare")
    stop(sQuote("ar"), " must be of class ", sQuote("sdare"))
  if (he && class(h) != "sdhee")
    stop(sQuote("h"), " must be of class ", sQuote("sdhee"))

  log.s <- log10(s)
  NH <- length(f)
  N = 2*NH+1
  df <- 1/N
  V <- 2*sum(s*df)
  SD = sqrt(V)

  xx = log10(2*pi*f)
  if(is.null(xlim)) {
    xmin = min(xx) - 0.2
    xmax = max(xx) + 0.2
    XL = c(xmin, xmax)
  }
  else XL = xlim

  if(is.null(ylim)) {
    ymin = min(log.s)
    ymax = max(log.s)
    if(ymin < 0) ymin <- ymin*1.2
    else            ymin <- ymin/1.2
    if(ymax < 0) ymax <- ymax/1.2
    else             ymax <- ymax*1.2
    YL = c(ymin,ymax)
  }
  else YL = ylim

  XLabel = "frequency"
  if(method == "Multitaper") 
    YLabel = paste(K, taper, method, "Spectrum Estimate")
  else
    YLabel = paste(method, "Spectrum Estimate")
  title = paste("Power Spectrum Plot of ", series, sep="")

  main <- if(is.null(main)) title else main
  xlab <- if(is.null(xlab)) XLabel else xlab
  ylab <- if(is.null(ylab)) YLabel else ylab

  if (main == "") m3 = 0.1
  else m3 = 0.4
  par(cex.main=1.5, cex.lab=1.5, cex.axis=1.5, font.lab=1, xaxt="n", mai=c(0.9,0.9,m3,0.1))
  plot(XL, YL, type="n", cex=0.5, xlab=xlab[1], ylab=ylab[1], main=main[1])

  if(plot.ci) {
    ls.ci <- log10(x$spectrum.ci)
    polygon(c(xx[1],xx,xx[NH],rev(xx)), c(ls.ci[1,1],ls.ci[,2],ls.ci[NH,1],
            rev(ls.ci[,1])), col="grey", border=NA)
  }
  col <- if(are) "grey" else "black"
  points(xx, log.s, type="o", pch=20)

  if (are) {
    PS_AR1 <- ar$psa
    Q2 = qchisq(2*pnorm(1)-1, 2) # 68% percentage point of the chisq(2) 
                                # distribution, i.e. P[chisq(2)<Q2]=0.95
    uPS_AR1 = 1/(1/sqrt(PS_AR1)-sqrt(Q2/N)/SD)^2 # see equation (448b) on pg 448
                                                 # of Percival and Walden
    lPS_AR1 = 1/(1/sqrt(PS_AR1)+sqrt(Q2/N)/SD)^2 # "Spectral Analysis for 
                                                 # Physical Applications"
    Q2 = qchisq(0.95, 2) # 95% percentage point of the chisq(2) distribution, 
                        # i.e. P[chisq(2)<Q2]=0.95
    u2PS_AR1 = 1/(1/sqrt(PS_AR1)-sqrt(Q2/N)/SD)^2 # see equation (448b) on 
                                                  # pg448 of Percival and Walden
    l2PS_AR1 = 1/(1/sqrt(PS_AR1)+sqrt(Q2/N)/SD)^2 # "Spectral Analysis for 
                                                  # Physical Applications"
    points(xx, log.s, type="o",pch=20,cex=0.5)
    points(xx, log10(PS_AR1), type="l",col="red")
    points(xx, log10(uPS_AR1), type="l",lty=2,col="red")
    points(xx, log10(u2PS_AR1), type="l",lty=2,col="red")
    points(xx, log10(lPS_AR1), type="l",lty=2,col="red")
    points(xx, log10(l2PS_AR1), type="l",lty=2,col="red")
  }
  if (he) {
      L <- h$L; M <- h$M; u = seq((L+1),M);
      points(xx[u], log10(h$psa), type="l", col="blue", lwd=2)
  }
  if (xaxt=="s") {
    par(xaxt="s")
    TP = trunc(log10(N))
    Frequencies = c(10^(seq(-TP,-1)), 1/2)
    axis(1, log10(2*pi*Frequencies), Frequencies)
  }
}

#ffe constructor
ffe <- function(scale, fluctuation, order = NA, method = "", series = "",
       call = match.call())
{
  structure(
    list(scale = scale, fluctuation = fluctuation, order = order, method =
         method, series = series, call = call),
    class = "ffe")
}

#ffe print
print.ffe <- function(x, ...)
{
  cat("order = ", x$order, ", Number of Scales = ", length(x$scale), "\n", sep="")
}

#ffe plot
plot.ffe <- function(x, h = NULL, plot.ci = TRUE, type = "o", xlim = NULL,
            ylim = NULL, main = NULL, xlab = NULL, ylab = NULL, ...)
{
  Scale=x$scale
  FF=x$fluctuation
  NS=length(Scale)
  he <- if(is.null(h)) FALSE else TRUE
  { if(he && class(h) != "tdhee")
      stop(sQuote("h"), " must be of class ", sQuote("tdhee"))
    else if(he) {
      L <- h$L; M <- h$M
      H=h$H; dH=h$stdH; Q <- log10(exp(h$q)); C <- 10^Q; dQ <- h$stdq
      dC <- C*dQ*log(10)
      LIndex = 1
      while(Scale[LIndex] < L) LIndex = LIndex + 1 
      MIndex =  LIndex
      while((Scale[MIndex] < M) && (MIndex < NS)) MIndex = MIndex + 1
    }
    else {
      LIndex <- 1
      MIndex <- NS
    }
  }
 
  Range = seq(LIndex,MIndex)
  lScale = log10(Scale)
  lFF = log10(FF)

  title = paste("DFA Plot of", x$series, "with order", x$order)

  XLabel = "log10(Scale)"
  YLabel = "log10(Fluctuation Function)"

  main <- if (is.null(main)) title else main
  xlab <- if (is.null(xlab)) XLabel else xlab
  ylab <- if (is.null(ylab)) YLabel else ylab

  par(cex.main=1.5, cex.lab=1.5, cex.axis=1.5, font.lab=1, xaxt="n",
      mai=c(0.9,0.9,0.4,0.4))
  plot(lScale, lFF, type=type, pch=20, xlab=xlab, ylab=ylab, xlim=xlim,
       ylim=ylim, main=main)

  if(he) {
    x <- lScale[Range]; y <- Q+H*x
    points(x, y, type="l", col="red")
    if (plot.ci) {
      z = sqrt((dH*(x^2-2*mean(x)*x))^2+dQ^2)
      points(x, Q+H*x-z, type="l", lty=2, col="red")
      points(x, Q+H*x+z, type="l", lty=2, col="red")
    }
  }

  par(xaxt="s")
  N = Scale[NS]
  TP = trunc(log10(N))
  ScaleL = 10^seq(1,TP)
  axis(1, log10(ScaleL), ScaleL)

  if(he) {
    S1 = paste("H = ", as.character(round(H, digits=2)), sep="")
    text(min(lScale)+0.8*(max(lScale)-min(lScale)), 
        min(lFF)+0.2*(max(lFF)-min(lFF)), cex=2,S1,col="red")
  }
}

#cse constructor
cse <- function(frequency, cross.spectrum, coherence = NA, amplitude = NA,
       phase = NA, ntaper = NA, coherence.ci = NA, phase.ci = NA, series = "",
       iseries.coherence.ci = NA, taper = "", weight = "", method = "", call =
       match.call())
{
  structure(
    list(frequency = frequency, cross.spectrum = cross.spectrum, coherence =
         coherence, amplitude = amplitude, phase = phase, ntaper = ntaper,
         series = series, coherence.ci = coherence.ci, phase.ci = phase.ci,
         method = method, iseries.coherence.ci = iseries.coherence.ci, taper =
         taper, weight = weight, call = match.call()),
    class = "cse")
}

#cse print
print.cse <- function(x, ...)
{
    NH <- length(x$frequency)
    N <- 2*NH+1
    cat("K = ", x$ntaper, ", N = ", N, ", NH = ", NH, "\n", sep="")
    # Estimation of variance conservation
#    df = 1/N
    #cat("Time Series Correlation =", round(cor(x,y),3))
#    cat("Correlation through the multitaper =",
#        round(2*sum(Re(x$cross.spectrum)*df),3), "\n")
}

#cse plot
plot.cse <- function(x, type = "o", main = rep(NULL,3), xlab = rep(NULL,3),
            ylab = rep(NULL,3), plot.ci = TRUE, ...)
{
  f <- x$frequency
  taper <- x$taper
  method <- x$method
  NH <- length(f)
  N <- 2*NH+1
  xx = log(2*pi*f)

  K <- x$ntaper
  Coh <- x$coherence
  Coh.ci <- x$coherence.ci
  AmpS <- x$amplitude
  PhS <- x$phase
  PhS.ci <- x$phase.ci
  isc = x$iseries.coherence.ci

  XLabel = rep("Frequency",3)
  YLabel = c("Coherency Spectrum","Phase Spectrum","Amplitude Spectrum")

  title1 = paste("Coherence spectrum of ", x$series[1], " and ", x$series[2],
                "with",  K, taper, method)
  title2 = paste("Phase spectrum of ", x$series[1], " and ", x$series[2],
                "with",  K, taper, method)
  title3 = paste("Amplitude spectrum of", x$series[1], "and", x$series[2],
                "with",  K, taper, method)
  title <- c(title1,title2,title3)

  main <- if(is.null(main)) title else main
  xlab <- if(is.null(xlab)) XLabel else xlab
  ylab <- if(is.null(ylab)) YLabel else ylab

  lm <- length(main)
  if(lm < 3)
    main <- c(main,title[(lm+1):3])
  lxl <- length(xlab)
  if(lxl < 3)
    xlab <- c(xlab,XLabel[(lxl+1):3])
  lyl <- length(ylab)
  if(lyl < 3)
   ylab <- c(ylab,YLabel[(lyl+1):3])

  TP = trunc(log10(N))
  FrequenciesN = 10^(seq(-TP,-1))
  FrequenciesC = 10^(seq(-TP,-1))

  par(mfrow=c(3,1),cex.main=1.5, cex.lab=1.5, cex.axis=1.5, font.lab=1,
     mai=c(0.6,0.7,0.3,0.5),xaxt="n")
  xmin <- min(xx); xmax <- max(xx); xlim <- c(xmin,xmax)

  ymin <- min(Coh, Coh.ci); ymax <- max(Coh, Coh.ci); ylim <- c(ymin,ymax)
  plot(c(xmin,xmax), c(ymin,ymax), type="n", cex=0.5, xlab=xlab[1],
       ylab=ylab[1], main=main[1])
  if(plot.ci) {
    polygon(c(xx[1],xx,xx[NH],rev(xx)), c(Coh.ci[1,1],Coh.ci[,2],Coh.ci[NH,1],
            rev(Coh.ci[,1])), col="grey", border=NA)
  }
  points(xx, Coh, type="o", pch=20)
  for(i in 1:length(isc)) abline(isc[i], 0, lty=2)
  par(xaxt="s")
  axis(1, log(2*pi*FrequenciesN), FrequenciesC)
  axis(4, at=isc, labels=names(isc))
  mtext("CDF for Independent Data", side=4, line=2.5, cex=0.8)

  par(xaxt="n")
  ymin <- min(PhS, PhS.ci); ymax <- max(PhS, PhS.ci); ylim <- c(ymin,ymax)
  plot(c(xmin,xmax), c(ymin,ymax), type="n", cex=0.5, xlab=xlab[2],
       ylab=ylab[2], main=main[2])
  if(plot.ci) {
    polygon(c(xx[1],xx,xx[NH],rev(xx)), c(PhS.ci[1,1],PhS.ci[,2],PhS.ci[NH,1],
            rev(PhS.ci[,1])), col="grey", border=NA)
  }
  points(xx, PhS, type="o", pch=20)
  par(xaxt="s")
  axis(1, log(2*pi*FrequenciesN), FrequenciesC)

  par(xaxt="n")
  plot(xx, AmpS, type="o", pch=20, cex=0.5, xlab=xlab[2], ylab=ylab[3],
      main=main[3])
  par(xaxt="s")
  axis(1, log(2*pi*FrequenciesN), FrequenciesC)
}

#sdhee constructor
sdhee <- function(H, b, c = log(b), asdH = NA, sdH = NA, sdc = NA,
         L = NA, M = NA, method = "", pse = "", psa = NA, 
         call = match.call())
{
  structure(
    list(H = H, b = b, c = c, asdH = asdH, sdH = sdH, sdc = sdc,
         L = L, M = M, method = method, 
         pse = pse, psa = psa, call = call),
    class = "sdhee")
}

#sdhee print
print.sdhee <- function(x, ...)
{
  cat("Low frequency cutoff index = ", x$L, ", High frequency cutoff index = ", x$M, "\n", sep="")
  cat("H = ", round(x$H,3),
      ", An asymptotic standard deviation of the estimated H = ",round(x$asdH,3), sep="")
  if(!is.na(x$sdH)) cat(", std(H) = ", round(x$sdH,3), sep="")
  cat("\nb = ", round(x$b,3), ", c =log(b)= ", round(x$c,3), sep="")
  if(!is.na(x$sdc)) cat(", std(c) = ", round(x$sdc,3), sep="")
  cat("\n")
}

#sdare constructor
sdare <- function(phi, sdphi = NA, psa = NA, pse = "", method = "",
         call = match.call())
{
  structure(
    list(phi = phi, sdphi = sdphi, psa = psa, pse = pse, method = method,
         call = call),
    class = "sdare")
}

#sdare print
print.sdare <- function(x, ...)
{
  if (is.na(x$sdphi)) cat("Estimated lag-one autocorrelation = ", round(x$phi,2), "\n", sep="")
  else cat("Estimated lag-one autocorrelation = ", round(x$phi,2), "+/-", round(x$sdphi,2), "\n", sep="")
}


#tdhee constructor
tdhee <- function(H, stdH = NA, r = NA, q = NA, stdq = NA, L = NA,
         M = NA, method = "", ffe = "", call = match.call())
{
  structure(
    list(H = H, stdH = stdH, r = r, q = q, stdq =stdq, L = L,
         method = method, M = M, ffe = ffe, call = call),
    class = "tdhee")
}

#tdhee print
print.tdhee <- function(x, ...)
{
  cat("H = ", round(x$H, digits=3), "+/-", round(x$stdH,3), "\n", sep="")
  cat("r = ", round(x$r,3), ", q =log(r)= ", round(x$q,3), "+/-", round(x$stdq,3), "\n", sep="")
  invisible(x)
}

#sdf.test print
print.sdf.test <- function(x, ...) {
  cat("T = ", round(x$T,2), ", p = ", round(x$p,2), "\n", sep="")
}

#gfit.test plot
plot.Gtest <- function(x, ...) {
  l <- as.numeric(dimnames(x)$ts.length)
  l1 = min(l)
  l2 = max(l)
  type <- dimnames(x)$type
  test <- dimnames(x)$test
  par(mfcol=c(1,2))
  x1 <- min(x)
  x2 <- max(x)
  ylim <- c(x1, x2)
  plot(l,x[,1,1],main=type[1],xlab="time series length", ylab =
      "Probability", type="b",ylim=ylim)
  lines(l, x[,2,1], type="b", lty=2)
  legend(l1+0.03*(l2-l1), x1+0.09*(x2-x1), legend=test, lty=1:2)

  plot(l,x[,1,2],main=type[2],xlab="time series length", ylab =
      "Probability", type="b",ylim=ylim)
  lines(l, x[,2,2], type="b", lty=2)
  legend(l1+0.03*(l2-l1), x1+0.09*(x2-x1), legend=test, lty=1:2)
}

#trend.test print
print.trend.test <- function(x, digits = 4, ...) {
  Trend <- x$trend; Intercept <- x$intercept; trend.est <- x$trend.est
  Sd <- x$sd; p <- x$p; N <- x$length
  lwidth=22
  cwidth=digits+3
  rwidth=8
  twidth=lwidth+2*cwidth+rwidth+7

  cat("Time Series Length = ", N, "\n", sep="")
  cat("Intercept = ",round(Intercept,digits), ", Trend = ", round(Trend,digits), "\n", sep="");
  cat("Residuals: Standard Deviation = ",round(Sd,digits),"\n", sep="")

  cat("Probability to detect the trend (test power) = ", 100*p, "%\n", sep="")

  cat(rep("=",twidth),"\n",sep="")
  cat(format("Residuals Model",width=lwidth,justify="centre"),"|", 
      format("95% trend CI",width=(2*cwidth+5),justify="centre"),"|",
      format("N",width=rwidth,justify="centre"),"\n", sep="")
  cat(rep("-",twidth),"\n",sep="")

  for(i in 1:nrow(trend.est)) {
    if(!any(is.na(trend.est[i,]))) {
      model <- dimnames(trend.est)[[1]][i]
      cat(format(model, width=lwidth,justify="centre"),"| [",
        format(round(Trend-trend.est[i,1],digits=digits), nsmall=digits,
        width=cwidth, justify="left"), ",",
        format(round(Trend+trend.est[i,1],digits=digits), nsmall=digits,
        width=cwidth,justify="left"),"] |",
        format(round(trend.est[i,2]), width=rwidth, justify="right"),
        "\n",sep="")
    }
  }
  cat(rep("=",twidth),"\n",sep="")
  cat("N - number of points required to detect the observed trend \n")
}

#hconv plot
plot.Hconv <- function(x, plot.color = TRUE, ...)
{
  H = x$H
  bH = x$bH
  T = x$T
  methods = dimnames(bH)$methods
  lms = length(methods)
  order = x$order
  # PLOT ERRORS IN ESTIMATES OF H AND THEIR STANDARD DEVIATIONS
  Title = "Hurst Exponent Estimation (H = "
  Title = paste(Title, as.character(H),sep="");
  Title = paste(Title, ")",sep="");

  x1 = min(T)
  x2 = max(T)
  XL = c(x1, x2)
  y2 = 1.1*max(abs(bH))
  y1 = -0.02*y2
  YL = c(y1, y2)

  XLab = "N"
  YLab = "Absolute value of the bias of the estimated Hurst exponent"
  par(cex.main=2, cex.sub=1.5, cex.lab=1.7, cex.axis=2, font.lab=1,
      mai=c(0.9,0.9,0.4,0.1), xaxt="n")
  Symbols = c(19, 22, 15, 24, 17)
  if(plot.color) {
    Colors = c("green","violet","red","blue","orange")
    Lines = rep(1,5)
  }
  else  {
    Colors = rep("black",5)
    Lines = seq(1,5)
  }
  plot(T, abs(bH[1,]), type="o", lwd=2, pch=Symbols[1], xlim=XL, ylim=YL,
       xlab=XLab, ylab=YLab, col=Colors[1], lty=Lines[1], main=Title)
  for (j in 2:lms) {
    points(T, abs(bH[j,]), type="o", lwd=2, pch=Symbols[j], cex=1.3,
           col=Colors[j], lty=Lines[j])
  }
  abline(h=0, col="black", lwd=2, lty="dotted");
  par(xaxt="s")
  axis(1, T, T)
  methods[methods=="dfa.lse"]=paste("DFA", " LSE", sep=as.character(order))
  methods[methods=="pgram.gphe"]="Periodogram GPHE"
  methods[methods=="mtm.gphe"]="MTM GPHE"
  methods[methods=="pgram.gspe"]="Periodogram GSPE"
  methods[methods=="mtm.gspe"]="MTM GSPE"
  legend(x="topright", legend=methods, pch=Symbols, col=Colors, lty=Lines,
         lwd=2, cex=1.7)
}

#Htest plot
plot.Htest <- function(x, plot.panel = 2, plot.color = TRUE, ...)
{
  plot1panel <- function (x, plot.color)
  {
    H = x$H; bH = x$bH; sdH = x$sdH; asdH = x$asdH
    methods = dimnames(bH)$methods
    order = x$order
    N = length(H)
    lms=length(methods)
    tmpseq=seq(1,lms)
    Title = "Comparison of the Hurst exponent estimation methods"
    x1 = min(H) - 0.05
    x2 = max(H) + 0.05
    XL = c(x1,x2)
    y1 = 1.6*min(bH-sdH)
    y2 = 1.1*max(bH+sdH)
    YL = c(y1,y2)
    XLab = "Hurst Exponent"
    YLab = "Bias and SD of the estimated Hurst exponent"

    par(cex.main=2, cex.sub=1.5, cex.lab=1.7, cex.axis=2, font.lab=1,
        mai=c(1.3,0.9,0.3,0.2))
    if(plot.color) {
      Colors = c("green","violet","red","blue","orange")
      EBColors = c("black","brown")
      EBLines = c(1,1) 
    }
    else {
      Colors = rep("black",5)
      EBColors = rep("black",2)
      EBLines = c(1,3) 
    }
    Symbols = c(19,22,15,24,17)
    Shifts = c(-0.04,-0.02,0,0.02,0.04)
    plot(H+Shifts[1], bH[1,1:N], lwd=1, pch=Symbols[1], xlim=XL, ylim=YL,
         xlab="Hurst Exponent",ylab=YLab,col=Colors[1],main=Title)
    Plot_Error_Bars(H+Shifts[1],bH[1,1:N],sdH[1,1:N],Color=EBColors[1])
    if(methods[1] != "dfa.lse") 
      Plot_Error_Bars(H+Shifts[1],bH[1,1:N],rep(asdH[1],N),Color=EBColors[2])
    for (j in tmpseq[-1]) {
      points(H+Shifts[j],bH[j,1:N],lwd=1,pch=Symbols[j],cex=1.3,col=Colors[j])
      # Plot experimental Standard Errors
      Plot_Error_Bars(H+Shifts[j], bH[j,1:N], sdH[j,1:N], Color=EBColors[1],
                      lty=EBLines[1])
      # Plot limiting distribution Standard Errors
      if(methods[j] == "pgram.gphe")
        Plot_Error_Bars(H+Shifts[j], bH[j,1:N], rep(asdH[2],N),
                        Color=EBColors[2],lty=EBLines[2])
      if(methods[j] == "pgram.gspe")
        Plot_Error_Bars(H+Shifts[j], bH[j,1:N], rep(asdH[4],N),
                        Color=EBColors[2],lty=EBLines[2])
    }

    abline(h=0, col="black", lwd=2, lty="dotted")

    xc = seq(x1,x2,by=0.1)
    for (i in 1:length(xc)) abline(v=xc[i], lty="dashed")

    methods[methods=="dfa.lse"]=paste("DFA", " LSE", sep=as.character(order))
    methods[methods=="pgram.gphe"]="Periodogram GPHE"
    methods[methods=="mtm.gphe"]="MTM GPHE"
    methods[methods=="pgram.gspe"]="Periodogram GSPE"
    methods[methods=="mtm.gspe"]="MTM GSPE"
    legend(x="bottomleft", legend=methods, pch=Symbols, lty=1, lwd=2, cex=1.3,
           col=Colors)
    legend(x="bottomright", legend=c("Experimental SD","Asymptotic SD"),
           pch=c("-","-"), lty=EBLines, lwd=2, cex=1.3, col=EBColors,
           text.col=EBColors)
  }

  plot2panel <- function (x, plot.color)
  {
    H = x$H; bH = x$bH; sdH = x$sdH; asdH = x$asdH
    methods = dimnames(bH)$methods
    order = x$order
    N = length(H)
    lms = length(methods)
    tmpseq = seq(1, lms)
    Title = "Comparison of the Hurst exponent estimation methods"
    par(mfcol=c(1,2))
    x1 = min(H) - 0.05
    x2 = max(H) + 0.05
    XL = c(x1,x2)
    XLab = "H"
    Symbols = c(19, 22, 15, 24, 17)
    if(plot.color) { 
      Colors = c("green","violet","red","blue","orange")
      EBColors = c("black", "brown") 
    } else { 
      Colors = rep("black",5); EBColors = rep("black",2)
    }
    Shifts = c(-0.04,-0.02,0,0.02,0.04)

    # Panel (a)
    par(mfg=c(1,1))
    y1 = 1.8*min(bH)
    y2 = 1.1*max(bH)
    YL = c(y1,y2)
    YLab = "Bias of the estimated Hurst exponent"

    par(cex.main=2, cex.sub=1.5, cex.lab=1.7, cex.axis=2, font.lab=1,
        mai=c(1.3,0.9,0.3,0.2), xaxt="n")
    plot(H+Shifts[1], bH[1,], type="o", lwd=1, pch=Symbols[1], xlim=XL,
         ylim=YL, xlab=XLab, ylab=YLab, col=Colors[1])
    for (j in tmpseq[-1]) {
      points(H+Shifts[j], bH[j,], type="o", lwd=1, pch=Symbols[j], cex=1.3,
             col=Colors[j])
    }

    abline(h=0, col="black", lwd=2, lty="solid");

    xc = seq(x1, x2, by=0.1)
    for (i in 1:length(xc)) abline(v=xc[i], lty="dashed")

    par(xaxt="s")
    Xx <- as.numeric(dimnames(bH)$H)
    axis(1,Xx,Xx);

    methods[methods=="dfa.lse"]=paste("DFA", " LSE", sep=as.character(order))
    methods[methods=="pgram.gphe"]="Periodogram GPHE"
    methods[methods=="mtm.gphe"]="MTM GPHE"
    methods[methods=="pgram.gspe"]="Periodogram GSPE"
    methods[methods=="mtm.gspe"]="MTM GSPE"
    legend(0.45, y1+0.25*(y2-y1), legend=methods, pch=Symbols, lty=1, lwd=2,
           cex=1.3, col=Colors)

    #Panel (b)
    par(mfg=c(1,2))
    y1 = 0
    y2 = 1.1*max(sdH)
    YL = c(y1, y2)
    YLab = "SD of the estimated Hurst exponent"

    par(cex.main=2, cex.sub=1.5, cex.lab=1.7, cex.axis=2, font.lab=1,
        mai=c(1.3,0.9,0.3,0.2), xaxt="n")
    plot(H+Shifts[1], sdH[1,1:N], type="o", lwd=1, pch=Symbols[1], xlim=XL,
         ylim=YL, xlab=XLab, ylab=YLab, col=Colors[1])
    for (j in tmpseq[-1]) {
      points(H+Shifts[j], sdH[j,], type="o", lwd=1, pch=Symbols[j], cex=1.3,
             col=Colors[j])
    }

    abline(h=asdH[2], col="black", lwd=2, lty="dashed");
    abline(h=asdH[4], col="black", lwd=2, lty="longdash");

    xc = seq(x1,x2,by=0.1)
    for (i in 1:length(xc)) abline(v=xc[i], col="black", lty="dashed")

    par(xaxt="s")
    axis(1,Xx,Xx);

    methods[methods=="dfa.lse"]=paste("DFA", " LSE", sep=as.character(order))
    methods[methods=="pgram.gphe"]="Periodogram GPHE"
    methods[methods=="mtm.gphe"]="MTM GPHE"
    methods[methods=="pgram.gspe"]="Periodogram GSPE"
    methods[methods=="mtm.gspe"]="MTM GSPE"
    legend(0.45, y1+0.25*(y2-y1), legend=methods, pch=Symbols, lty=1, lwd=2,
           cex=1.3,col=Colors)
  }

  Plot_Error_Bars = function(X,Y,dY,Color,lty=1)
  {
    dx = (max(X)-min(X))/100;
    N = length(X);
    Z1=Y-dY;
    for (i in 1:N) 
      lines(c(X[i]-dx,X[i]+dx), c(Z1[i],Z1[i]), lwd=2, col=Color, lty=lty)
    Z2=Y+dY
    for (i in 1:N) 
      lines(c(X[i]-dx,X[i]+dx), c(Z2[i],Z2[i]), lwd=2, col=Color, lty=lty)
    for (i in 1:N) 
      lines(c(X[i],X[i]), c(Z1[i],Z2[i]));
  }

  { if (plot.panel == 1) plot1panel(x, plot.color = plot.color)
    else if (plot.panel == 2) plot2panel(x, plot.color = plot.color)
    else stop()
  }
}
