ps.gphe <- function(x, L = 0, M = length(f), calcSD = FALSE, verbose = TRUE, pse = NULL, ...)
{
  if(class(x) != "pse") stop(sQuote("x"), " must be of class ", sQuote("pse"))
  f <- x$frequency
  s <- x$spectrum
  K <- x$ntaper
  if (is.null(pse)) pse <- deparse(substitute(x))
  if (M < L) stop(sQuote("M"), " must be larger than ", sQuote("L"))
  N = 2*length(f)+1
  checkparam(L,Lbound(M))
  checkparam(M,Mbound(L,N))
  Q = M - L
  u = seq((L+1),M)
  sf = (2*pi*f[u])^2
  x = -log(sf)
  cx = x - mean(x)
  S = sum(cx^2)
  # Estimation of parameters (c,d)
  d = sum(cx*log(s[u]))/S # see an equation on page 663 in McCoy, Walden, and Percival (1998)
  H = d + 0.5
# An asymptotic value of the standard deviation the estimator of H, 
# see equation (7) on page 24 in Hurvich, Deo, and Brodsky (1998)
  asdH = pi/sqrt(24*Q) 
#  b = mean(s[u]*sf^d) # equation from Robinson (1995)
# The following equation for b conserves the variance, i.e. the integral of the fit over 
# the fitted region is equal to the integral of the spectrum over the same region  
  b = mean(s[u])/mean(sf^(-d)) 
  c = log(b)

  psa <- b*(sf^(-d))
  # Estimation of covariance matrix for (c,d)
  # see equation (11) on page 663 of [4]
  sdc=NA
  sdH=NA
  if (calcSD) {
    psip = trigamma(K)
    vX = cbind(rep(1,Q), x)
    tvX = t(vX)
    A = tvX%*%vX
    iA = solve(A)
    Sigma = array(0, c(Q,Q))
    for (i in 1:Q)
      for (j in 1:Q) if (abs(i-j) <= (K+1)) Sigma[i,j] = psip*(1-abs(i-j)/(K+1))
    B = tvX%*%Sigma%*%vX
    C = iA%*%B%*%iA
    sdc = sqrt(C[1,1])
    sdH = sqrt(C[2,2])
  }
  method <- "Geweke-Porter-Hudak Estimator"
  res <- sdhee(H = H, b = b, c = c, asdH = asdH, sdH = sdH, sdc = sdc,
               L = L, M = M, method = method, pse = pse, psa = psa, 
               call = match.call())

  if(verbose) print(res)
  invisible(res)
}
