ps.gspe <- function(x, L = 0 , M = length(f), interval = c(0,1.5), verbose = TRUE, pse = NULL, ...)
{
  G <- function(x) mean(s[u]*sf^x)
  R <- function(y) log(G(y))-y*mean(log(sf)) # Equation (2.2) from 
                                             # P.M.Robinson (1995b)
  if(class(x) != "pse") stop(sQuote("x"), " must be of class ", sQuote("pse"))
  if (is.null(pse)) pse <- deparse(substitute(x))
  f <- x$frequency
  s <- x$spectrum
  if (M < L) stop(sQuote("M"), " must be larger than ", sQuote("L"))
  N = 2*length(f)+1
  checkparam(L,Lbound(M))
  checkparam(M,Mbound(L,N))
  Q = M - L
  u = seq((L+1),M)
  sf = (2*pi*f[u])^2
  # Estimation of parameters (c,d)
  out = optimize(R, interval-0.5)
  d = out$minimum
  H = d + 0.5
  asdH = 1/(2*sqrt(Q)) # asymptotic value of the standard deviation of the estimator of H 
                                 #             (see the documenation for references)
#  b = G(d) # equation from Robinson (1995)
# The following equation for b conserves the variance, i.e. the integral of the fit over 
# the fitted region is equal to the integral of the spectrum over the same region  
  b = mean(s[u])/mean(sf^(-d))
  c = log(b)
  psa <- b*(sf^(-d))

  method <- "Gaussian Semiparametric Estimator"
  res <- sdhee(H = H, b = b, c = c, asdH = asdH, L = L, M = M, 
                     method = method, pse = pse, psa = psa, call = match.call())

  if(verbose) print(res)
  invisible(res)
}
