ps.mtm <- function(x, dt = c("dpss","sine"), wt = c("adapt","uniform"),
          K = 3, cl =  0.95, verbose = TRUE, na.action = na.fail,
          demean = TRUE, series = NULL, ...)
{
  weight <- match.arg(wt)
  if (is.character(dt)) dt <- match.arg(dt)
  if (is.null(series)) series <- deparse(substitute(x))
  x <- check.ts(x = x, name = series, na.action = na.action, demean = demean)
  N <- length(x)
  NH <- trunc(N/2)
  f <- c(1:NH)/N

  ct <- check.taper(dt = dt, N = N, K = K, ...)
  h <- ct$h; 
  v <- ct$v; 
  taper <- ct$taper
  k1 <- rep(1,K)

  w <- mvfft(h*matrix(x,N,K))[2:(NH+1),]
  Smtk <- Mod(w)^2

  if(taper == "dpss" && weight == "adapt") {
    amtm <- a.mtm(Smtk = Smtk, N = N, v = v, NH = NH, K = K)
    Smt <- amtm$Smt; edf <- amtm$edf; wt <- amtm$wt
  }
  else {
    weight <- "uniform"
    Smt <- apply(Smtk, 1, mean) # Eq. (369a) from the Percival and Walden textbook
    edf <- 2*K*rep(1,NH)
    wt <- matrix(1,NH,K)
  }

  #jackknife confidence intervals
  Smt.ci <- matrix(0,NH,2)
  Smtkjk <- matrix(0,NH,K)
  for(i in 1:K) # Eq. (14) from Thomson 2007
    Smtkjk[,i] <- ((wt[,-i]^2*Smtk[,-i])%*%k1[-1])/((wt[,-i]^2)%*%k1[-1])
  Var <- apply(log(Smtkjk), 1, var)*(K-1)^3/K/(K-1/2) # Eq. (18) from Thomson 2007

  F <- exp(qt((1+cl)/2, edf)*sqrt(Var)) # Eq.(2.49) from Thomson & Chave 1993
  Smt.ci[,1] <- Smt*F
  Smt.ci[,2] <- Smt/F

  res <- pse(frequency = f, spectrum = Smt, spectrum.ci = Smt.ci, cl = cl,
             ntaper = K, series = series, taper = taper, weight = weight,
             method = "Multitaper", call = match.call())
  if(verbose) print(res)
  invisible(res)
}
