ps.pgram <- function(x, cl = 0.95, verbose = TRUE, na.action = na.fail, demean =
            TRUE, series = NULL, ...)
{
  if (is.null(series)) series <- deparse(substitute(x))
  x <- check.ts(x = x, name = series, na.action = na.action, demean = demean)
  N = length(x)
  #NH = round((N-1)/2) # highest Fourier frequency
  NH <- trunc(N/2)
  w = fft(x)[2:(NH+1)]
  s <- (abs(w)^2)/N # equation (1.4) in [2]
  f = c(1:NH)/N

  #equivalent (chi-square) degrees of freedom
  edf <- 2

  #p% confidence interval
  z <- qchisq((1+cl)/2,edf)
  s.ci <- matrix(0,NH,2)
  s.ci[,1] <- s*z
  s.ci[,2] <- s/z

  res <- pse(frequency = f, spectrum = s, spectrum.ci = s.ci, cl = cl, 
             ntaper = 1, series = series, method = "Periodogram", call
= match.call())
  if(verbose) print(res)
  invisible(res)
}
