#included from the R package 'waveslim'
#Author: Brandon Whitcher <brandon.j.whitcher@gsk.com>
#URL: http://www.image.ucar.edu/~whitcher/
#License: GPL(>= 2)
#Modified by Josh Mayer <joshua.a.mayer@gmail.com>

dpss.taper <- function(n, K = 3, nmax = 2^(ceiling(log(n,2))), ...)
{
  if(n > nmax)
    stop("length of taper is greater than nmax")
  if(K < 1)
    stop("positive order (K) required")
  w <- K/(2*n)
  if(w > 0.5)
    stop("half-bandwidth parameter (w) is greater than 1/2")
  v <- matrix(0, nrow = nmax, ncol = (K + 1))
  storage.mode(v) <- "double"
  out <- .Fortran("dpss", nmax = as.integer(nmax), kmax = as.integer(K),
                  n = as.integer(n), w = as.double(w), v = v, 
                  sig = double(K + 1), totit = integer(1), sines = double(n),
                  vold = double(n), u = double(n), scr1 = double(n),
                  ifault = integer(1), PACKAGE="PowerSpectrum")
  invisible(
    structure(
      list(eigenvectors = out$v[1:n, 1:K], eigenvalues = out$sig[-1] + 1),
      class="dpss.taper"))
}

sine.taper <- function(n, K = 3, ...)
{
  if(K < 1) stop("positive order (K) required")
  tapers <- matrix(0,n,K)
  for(i in 1:K) tapers[,i] <- sqrt(2/(n+1))*sin((pi*i*1:n)/(n+1))
  invisible(
    structure(
      tapers,
      class="sine.taper"))
}
