trend.test <- function(x, ar = NULL, h = NULL, a = 0.05, p = 0.5, verbose =
              TRUE, na.action = na.fail, demean = TRUE, series = NULL)
{
  if (is.null(series)) series <- deparse(substitute(x))
  x <- check.ts(x = x, name = series, na.action = na.action, demean = demean)
  N <- length(x)
  he <- if(is.null(h)) FALSE else TRUE
  are <- if(is.null(ar)) FALSE else TRUE
  if(he && class(h) != "sdhee")
      stop(sQuote("h"), " must be of class ", sQuote("sdhee"))
  if(are && class(ar) != "sdare")
      stop(sQuote("ar"), " must be of class ", sQuote("sdare"))
  res <- matrix(NA,3,2)
  nres <- list(c("White Noise", "Autoregressive (1)", "Power Law"),
                        c("95% trend CI", "N"))
  names(nres) <- c("Residuals Model","Estimates")
  dimnames(res) <- nres
  # a quantile
  za = qnorm(1-a/2)
  # p quantile
  zp = qnorm(p)
  t <- seq(1,N)
  LM = lm(x ~ t)
  Intercept = LM$coeff[1]
  names(Intercept)<-NULL
  Trend = LM$coeff[2]
  names(Trend)<-NULL
  dtx = LM$residuals # residuals
  Sd = sd(dtx)
  C = sqrt(12)*Sd
  trend.ci = za*C*N^(-3/2);
  trend.est = ((za+zp)*C/abs(Trend))^(2/3)
  res[1,1] <- trend.ci
  res[1,2] <- trend.est

  if(are) {
    phi <- ar$phi
    C = sqrt(12)*Sd*sqrt((1+phi)/(1-phi))
    trend.ci = za*C*N^(-3/2)
    trend.est = ((za+zp)*C/abs(Trend))^(2/3)
    res[2,1] <- trend.ci
    res[2,2] <- trend.est
  }
  if(he) {
    H <- h$H; b <- h$b
    C = sqrt(36*b*(1-H)/((1+H)*gamma(2*H+1)*sin(pi*H)))
    trend.ci = za*C*N^(H-2);
    trend.est = ((za+zp)*C/abs(Trend))^(1/(2-H))
    res[3,1] <- trend.ci
    res[3,2] <- trend.est
  }
  result <- structure(
              list(intercept = Intercept, trend = Trend, sd = Sd, length = N,
                   p = p, trend.est = res),
              class = "trend.test")
  if(verbose) print(result)
  invisible(result)
}
