\name{dfa.ffe}
\alias{dfa.ffe}
\title{Detrended Fluctuation Analysis}

\description{Detrended Fluctuation Analysis (DFA) was originally proposed in [1] and is described in details in [2]. It  works as follows. In the beginning a cumulative sum time series is generated from the original time series. It might be thought as a random walk which increments are equal to the values of the original time series. Then the cumulative time series is split into segments of size \eqn{s} and is approximated in the least squares sense in each segment by a polynomial of a certain \eqn{order}. In most cases \eqn{order} is chosen between 1 and 5. The standard deviation of the best fit residuals is calculated for each segment and then averaged over all segments. Let's call this value \eqn{F(s)}. After that the segment size is increased and the above described procedure is repeated. Therefore for each value of \eqn{s} we obtain a corresponding value \eqn{F(s)}, which is called fluctuation function.  This function estimates \eqn{F(s)}.

In case time series autocorrelation function decays as \eqn{at^{2H-2}} when \eqn{t \rightarrow \infty} or equivalently its spectral density increases as \eqn{b\lambda^{1-2H}} when \eqn{\lambda \rightarrow 0} its fluctuation function \eqn{F(s)} scales as \eqn{rs^H} (see [3,4]). Thus to extract the Hurst exponent \eqn{F(s)} could be regressed against a straight line in log-log coordinates from the lower scale \eqn{L} to the maximum scale \eqn{M} (as in [1,2]). This regression is done by the \code{dfa.lse} function. 

The output can be visualized using \code{plot} function which actually calls \code{plot.ffe}.
}

\usage{
dfa.ffe(x, order = 1, verbose = TRUE, na.action = na.fail, 
    demean = TRUE, series = NULL, ...)
}

\arguments{
\item{x}{a vector containing a uniformly sampled real valued time series.}
\item{order}{an order of the polynomials used in local detrending. It should be between 1 and 5.}
\item{verbose}{a logical flag. If TRUE (the default), prints information while
executing.}
\item{na.action}{a function to be called to handle missing values.}
\item{series}{a name for the time series. Default: deparse(substitute(x)).}
\item{demean}{a logical flag. If TRUE (the default), the mean value of \code{x} is set to 0.}
\item{...}{}
}

\value{
an object of class \code{ffe} with the following values set:
\item{fluctuation}{a fluctuation function.}
\item{scale}{a vector of scales.}
\item{order}{the order of the polynomials used in local detrending.}
\item{method}{a fluctuation function estimation method used, in this case "Detrended Fluctuation Analysis".}
\item{series}{a name of the time series. Default: deparse(substitute(x)).}
\item{call}{the matched call to \code{dfa.ffe}}
}
\references{ 
[1] C. Peng, C., S. Buldyrev, A. Goldberger, S. Havlin, M. Simons, and H. Stanley (1993), Finite-size effects on long-range correlations: Implications for analyzing dna sequences, \emph{Phys.\ Rev.\ E} \bold{47}, 3730--3733.

[2] J. Kantelhardt, E. Koscielny-Bunde, H. Rego, S. Havlin, and A. Bunde (2001),
Detecting long-range correlations with detrended fluctuation analysis, \emph{Physica A} \bold{295}, 441--454.

[3] M. Taqqu, V. Teverovsky, and W. Willinger (1995), Estimators for long-range dependence: an empirical study, \emph{Fractals} \bold{3}, 785--798.

[4] C. Heneghan and G. McDarby (2000), Establishing the relation between detrended fluctuation analysis and power spectral density analysis for stochastic processes. \emph{Phys.\ Rev.\ E} \bold{62}, 6103--6110.
}
\seealso{\code{\link{ffe}},  \code{\link{dfa.lse}},  \code{\link{plot.ffe}}}
\examples{
library(PowerSpectrum)
x = dfa.ffe(CET_1659_2008)
plot(x)
}
\keyword{ts}
