\name{dfa.lse}
\alias{dfa.lse}
\title{Detrended Fluctuation Analysis}

\description{Detrended Fluctuation Analysis (DFA) was originally proposed in [1] and is described in details in [2]. It  works as follows. In the beginning a cumulative sum time series is generated from the original time series. It might be thought as a random walk which increments are equal to the values of the original time series. Then the cumulative time series is split into segments of size \eqn{s} and is approximated in the least squares sense in each segment by a polynomial of a certain \eqn{order}. In most cases \eqn{order} is chosen between 1 and 5. The standard deviation of the best fit residuals is calculated for each segment and then averaged over all segments. Let's call this value \eqn{F(s)}. After that the segment size is increased and the above described procedure is repeated. Therefore for each value of \eqn{s} we obtain a corresponding value \eqn{F(s)}, which is called fluctuation function. \eqn{F(s)} is estimated by \code{dfa.ffe}.

In case time series autocorrelation function decays as \eqn{at^{2H-2}} when \eqn{t \rightarrow \infty} or equivalently its spectral density increases as \eqn{b\lambda^{1-2H}} when \eqn{\lambda \rightarrow 0} its fluctuation function \eqn{F(s)} scales as \eqn{rs^H} (see [3,4]). Thus to extract the Hurst exponent \eqn{F(s)} is regressed against a straight line in log-log coordinates from the lower scale \eqn{L} to the maximum scale \eqn{M} (as in [1,2]). This regression is done by this function.

The output can be visualized using \code{plot} function which actually calls \code{plot.ffe}.
}

\usage{
dfa.lse(x, L = (3*x$order+9), M = round(x$scale[length(x$scale)]/4),
        verbose = TRUE, ffe = NULL, ...)
}

\arguments{
\item{x}{an object of class \code{ffe}}
\item{L}{a lower scale cut off.}
\item{M}{an upper scale cut off.}
\item{verbose}{a logical flag. If TRUE (the default), prints information while executing.}
\item{ffe}{the ffe object used}
\item{...}{}
}

\value{
An object of class \code{tdhee} with the following values set
\item{H}{an estimate of the Hurst exponent.}
\item{stdH}{a standard deviation of the estimator of \code{H}.} 
\item{r}{a fluctuation function scaling factor from \eqn{F(s) \sim rs^H}.}
\item{q}{\eqn{q=log(r)}.}
\item{stdq}{a standard deviation of the estimate of \code{q}.}
\item{L}{a lower scale cut off.}
\item{M}{an upper scale cut off.}
\item{ffe}{the name of the ffe object used. Default: deparse(substitute(x)).}
\item{method}{a Hurst exponent estimation method used, in this case "Least Squares Estimate".}
\item{call}{the matched call to \code{dfa.lse}}
}

\note{
\code{stdH} and \code{stdq} are estimated using a crude assumption that the residuals of the linear regression of a DFA curve in log-log coordinates are independent and normally distributed. Thus these values just give an idea about the true uncertainties. Unfortunately the theory that would describe distributions of \code{stdH} and \code{stdq} is still missing.
}

\references{ 
[1] C. Peng, C., S. Buldyrev, A. Goldberger, S. Havlin, M. Simons, and H. Stanley (1993), Finite-size effects on long-range correlations: Implications for analyzing dna sequences, \emph{Phys.\ Rev.\ E} \bold{47}, 3730--3733.

[2] J. Kantelhardt, E. Koscielny-Bunde, H. Rego, S. Havlin, and A. Bunde (2001), Detecting long-range correlations with detrended fluctuation analysis, \emph{Physica A} \bold{295}, 441--454.

[3] M. Taqqu, V. Teverovsky, and W. Willinger (1995), Estimators for long-range dependence: an empirical study, \emph{Fractals} \bold{3}, 785--798.

[4] C. Heneghan and G. McDarby (2000), Establishing the relation between detrended fluctuation analysis and power spectral density analysis for stochastic processes. \emph{Phys.\ Rev.\ E} \bold{62}, 6103--6110.
}
\seealso{\code{\link{dfa.ffe}}, \code{\link{ffe}}, \code{\link{tdhee}},  \code{\link{plot.ffe}}}
\examples{
library(PowerSpectrum)
cet.dfa.ffe <- dfa.ffe(CET_1659_2008)
cet.dfa.lse <- dfa.lse(cet.dfa.ffe)
plot(cet.dfa.ffe,h=cet.dfa.lse)
}
\keyword{ts}
