\name{gfit.test}
\alias{gfit.test}
\title{Test of the goodness-of-fit tests}
\description{This functions performs a Monte-Carlo kind of test of the two goodness-of-fit tests, Ljung-Box (see \code{pmt.test}) and spectral density (see \code{sdf.test}) tests [1-2]. It generates \eqn{s} time series of length \eqn{n} using a power law and an AR(1) models. Then it fits the power law time series by an AR(1) model and the AR(1) time series by a power law model and estimates the probability of rejecting the null hypothesis of a "true" model by the two goodness-of-fit tests. The \code{gfit.test} replicates the procedure described in [2] using functions implemented in this R package.}

\usage{
gfit.test(H = 0.8, phi = 0.5, sd.fd.res = 1, sd.ar.res = 1, 
          lfc = 0, hfc =2, s = 100, n = seq(400,2000,100), 
          verbose = TRUE, plot = TRUE)
}
\arguments{
\item{H}{a Hurst exponent value to be tested.}
\item{phi}{a lag one autocorrelation value to be tested.}
\item{sd.fd.res}{the standard deviation of the fractionally differenced process.}
\item{sd.ar.res}{the standard deviation of the AR(1) process.}
\item{lfc}{a number of the lowest Fourier frequences trimmed. Used in \code{sdf.test} only.}
\item{hfc}{a lower scale cut off. Thus M=trunc(n[i]/hfc). Used in \code{sdf.test} only.}
\item{s}{the number of samples to average over.}
\item{n}{a vector of time series lengths.}
\item{verbose}{a logical flag. If TRUE (the default), prints information while executing.}
\item{plot}{a logical value for whether or not to plot the results. Default: TRUE.}
}
\value{
A list of class \code{Gtest} with the following elements:
\item{p}{An array of probabilities of rejecting the null hypothesis that a fitted model (AR(1) or Power Law) is adequate for a realization of a process (Power Law or AR(1)) using the Ljung-Box and Spectral density tests. The output can be visualized using \code{plot} function which actually calls \code{plot.gfit.test}.}
}
\references{ 
[1] J. Beran (1992),  A Goodness-of-Fit Test for Time Series with Long Range Dependence, \emph{J.R. Statis. Soc. B} \bold{54}, 749-760.

[2] D.B. Percival, J.E. Overland, and H.O. Mofjeld (2001), Interpretation of North Pacific Variability as a Short- and Long-Memory Process, \emph{J. Climate} \bold{14}, 4545-4559.
}
\seealso{\code{\link{pmt.test}}, \code{\link{sdf.test}}}
\examples{
library(PowerSpectrum)
gfit.test(s=10, n = seq(400,1000,100))
}
\keyword{ts}
