\name{hurst.conv}
\alias{hurst.conv}
\title{Test of the Hurst exponent estimators convergence}

\description{This function estimates the biases of a given list of the Hurst exponent estimators for a given set of time series lengths for a fixed value of \eqn{H}. Synthetic time series are generated using ARFIMA(0,\eqn{H-0.5},0) model (\code{fracdiff.sim} function from \pkg{fracdiff} package). Results can be nicely plotted using the \code{plot} function.}

\usage{
hurst.conv(H = 0.8, T = seq(270,910,by=90), s = 100, order = 3, 
           lfc = 0, hfc = 18, methods = c("dfa.lse", "pgram.gphe", 
           "mtm.gphe", "pgram.gspe", "mtm.gspe"), 
           verbose = TRUE, plot = TRUE, ...)
}

\arguments{
\item{H}{a value of the Hurst exponent to be tested, where \eqn{0<H<2}.}
\item{T}{a vector of time series lengths.}
\item{s}{a number of samples to use.}
\item{order}{the order of the polynomials used in local detrending in DFA}
\item{lfc}{a number of the lowest Fourier frequences trimmed. In case lfc=0 then dfa.M=T[i], otherwise ps.L=lfc and dfa.M=round(T[i]/lfc).}
\item{hfc}{a lower scale cut off. Thus dfa.L=hfc and ps.M=trunc(T[i]/hfc).}
\item{methods}{a character string list specifying the methods for the Hurst exponent estimation. Default: c("dfa", "pgramgphe", "mtmgphe", "pgramgspe", "mtmgspe").}
\item{verbose}{a logical flag. If TRUE (the default), prints information while executing.}
\item{plot}{a logical value for whether or not to plot the results. Default: TRUE.}
\item{...}{Additional arguments passed to any of \code{dfa.ffe}, \code{dfa.lse}, \code{ps.pgram}, \code{ps.mtm}, \code{ps.gphe}, \code{ps.gspe} and \code{plot}. Note: Neither \code{m} (\code{dfa.lse}) nor \code{M} (\code{ps.gphe} and \code{ps.gspe}) should be set since they depend on the length of the time series and are therefore generated accordingly.}
}
\value{
A list of class \code{Hconv} with the following elements:
\item{H}{a true value of the Hurst exponent tested.}
\item{T}{a vector of time series lengths.}
\item{methods}{a character string list specifying the methods for the Hurst exponent estimation.}
\item{bH}{a bias of the estimated \code{H}. It is a matrix of size \code{length(methods)}x\code{length(T)} which (\eqn{i,j}) element is equal to the bias of the method number \eqn{i} for the time series length number \eqn{j}.}
}

\note{
To get a clear distinction between the different methods set \eqn{s} at least equal to 1000.
}

\seealso{\code{\link{dfa.ffe}}, \code{\link{ps.pgram}}, \code{\link{ps.mtm}}, \code{\link{ps.gphe}}, \code{\link{ps.gspe}}, \code{\link{plot.Hconv}}}
\examples{
library(PowerSpectrum)
hurst.conv(s=10)
}
\keyword{ts}
