\name{hurst.test}
\alias{hurst.test}
\title{Test of the Hurst exponent estimators bias and standard deviation}

\description{This function generates \eqn{s} time series of length \eqn{n} using ARFIMA(0,\eqn{H-0.5},0) model  (\code{fracdiff.sim} function from \pkg{fracdiff} package) for a vector of the values of \eqn{H} and calculate the bias and the standard deviation for a given list of the Hurst exponent estimators.}

\usage{
hurst.test(H = seq(0.5,1.1,by=0.1), T = 540, s = 100, order=3, lfc=0, 
  hfc=18, methods = c("dfa.lse","pgram.gphe","mtm.gphe",
  "pgram.gspe","mtm.gspe"), verbose = TRUE, plot = TRUE, ...)
}
\arguments{
\item{H}{a vector of the Hurst exponent values to be tested, where \eqn{0<H[*]<2}.}
\item{methods}{a character string list specifying the methods for the Hurst exponent estimation. By default it includes all the supported methods.}
\item{T}{a length of the time series to use.}
\item{s}{a number of samples to use.}
\item{order}{the order of the polynomials used in local detrending in DFA}
\item{lfc}{a number of the lowest Fourier frequences trimmed. Thus ps.L=lfc and dfa.M=round(T[i]/lfc). In case lfc=0 then dfa.M=T[i].}
\item{hfc}{a lower scale cut off. Thus dfa.L=hfc and ps.M=trunc(T[i]/hfc).}
\item{verbose}{a logical flag. If TRUE (the default), prints information while executing.}
\item{plot}{a logical value for whether or not to plot the results. Default: TRUE.}
\item{...}{Additional arguments passed to any of \code{dfa.ffe}, \code{dfa.lse}, \code{ps.pgram}, \code{ps.mtm}, \code{ps.gphe}, \code{ps.gspe} and \code{plot}.}
}
\value{
A list of class \code{Htest} with the following elements:
  \item{H}{a vector of the true values of the Hurst exponent tested.}
  \item{bH}{a bias of the estimated \code{H}. It is a matrix of size \code{length(methods)}x\code{length(H)} which (\eqn{i,j}) element is equal to the 
  bias of the method number \eqn{i} for the true value of \code{H} number \eqn{j}.}
  \item{sdH}{a standard deviation of the estimated \code{H}. It has the same structure as \code{bH}.}
}

\note{
To get a clear distinction between the different methods set \eqn{s} at least equal to 1000.
}

\seealso{\code{\link{dfa.ffe}}, \code{\link{ps.pgram}}, \code{\link{ps.mtm}}, \code{\link{ps.gphe}}, \code{\link{ps.gspe}}, \code{\link{plot.Htest}}}
\examples{
library(PowerSpectrum)
hurst.test(s=10)
}
\keyword{ts}
