\name{pmt.test}
\alias{pmt.test}
\title{Portmanteau tests}

\description{The portmanteau test is designed to see if the sample autocorrelations of the residuals for lags t =1,..,lag is consistent
with a hypothesis of zero mean white noise, where "lag" is taken to be relatively small in relation to the sample size N. Here we consider two variations on the portmanteau test, namely, the Box-Pierce test statistic and the Ljung-Box-Pierce test statistic [1]. \code{pmt.test} estimates the residuals for a given sample and a given model, AR1 or power law, and then calls \code{Box.text} function, which is a standard R function.
}
\usage{
pmt.test(x, m, lag = max(10,round(length(x)/20)),
         type = c("Ljung-Box","Box-Pierce"),
         na.action = na.fail, demean = TRUE,
         series = NULL)
}
\arguments{
\item{x}{a vector containing a uniformly sampled real valued time series.}
\item{m}{an object of class \code{sdhee} (generated by \code{ps.gphe} or
\code{ps.gspe}) or \code{sdare} (generated by \code{ps.ar1})}
\item{lag}{a maximum autocorrelation function time lag.}
\item{type}{test type, "Ljung-Box" or "Box-Pierce".}
\item{na.action}{a function to be called to handle missing values.}
\item{demean}{a logical flag. If TRUE (the default), the mean value of \code{x} is set to 0.}
\item{series}{a name for the series. Default: deparse(substitute(x)).}
}
\value{
\item{Bt}{an output of the \code{Box.text} function.}
\item{model}{a character string specifying the fitted model.}
}
\references{ 
[1] D.B. Percival, J.E. Overland, and H.O. Mofjeld (2001), Interpretation of North Pacific Variability as a Short- and Long-Memory Process, \emph{J. Climate} \bold{14}, 4545--4559.
}
\seealso{\code{\link{sdf.test}}}
\examples{
library(PowerSpectrum)
h <- ps.gspe(ps.mtm(hadcrut3gl_1850_2008))
pmt.test(hadcrut3gl_1850_2008, m=h)
}
\keyword{ts}
