\name{ps.gphe}
\alias{ps.gphe}
\title{Geweke-Porter-Hudak Estimator}

\description{
Geweke-Porter-Hudak Estimator (GPHE) is a linear fit of the time series power spectrum in log-log coordinates within a given frequency bandwidth. GPHE estimates the Hurst exponent together with its confidence intervals and a scaling factor \eqn{b} by fitting function  \eqn{f(\lambda)=b|\lambda|^{1-2H}} to a low-frequency part of the time series power spectrum by the least squares method. GPHE was originally proposed in [1] and rigorously justified in [2] and [3] for the case of the periodogram and in [4] for the multitaper.
}

\usage{
ps.gphe(x, L = 0, M = length(f), calcSD = FALSE, 
        verbose = TRUE, pse = NULL, ...)
}
\arguments{
\item{x}{an object of class \code{pse}, output from either \code{ps.pgram} or
\code{ps.mtm}.}
\item{L}{a number of the lowest Fourier frequences trimmed.}
\item{M}{a number of the highest Fourier frequency used.}
\item{calcSD}{a logical flag. If TRUE, calculates the standard deviations (see equation (11) in [4]) for the estimates of \eqn{H} and \eqn{c=log(b)} . It is a time consuming option. Default: FALSE.}
\item{verbose}{a logical flag. If TRUE (the default), prints information while executing.}
\item{pse}{the name of the pse object. Default: deparse(substitute(x)).}
\item{...}{}
}
\value{
An object of class \code{sdhee} with the following values set:
\item{H}{an estimate of the Hurst exponent.}
\item{sdH}{a standard deviation of the estimator of \code{H} (see equation (11) in [3]). GPHE only.} \item{asdH}{an asymptotic value of the standard deviation of the estimator of \code{H} based on the periodogram (see equation (7) on page 24 in [2] for GPHE and equation (4.1) on page 1640 in [1] for GSPE).}
\item{b}{an estimate of the scaling factor \eqn{b} from \eqn{f(\lambda)=b{\lambda}^{1-2H}}.}
\item{c}{\eqn{c=log(b)}.}
\item{sdc}{a standard  deviation of the estimator of \eqn{c=log(b)} (see equation (11) in [3]).}
\item{L}{a number of the lowest Fourier frequences trimmed.}
\item{M}{a number of the highest Fourier frequency used.}
\item{psa}{a power spectrum approximation of the form \eqn{b{\lambda}^{1-2H}}.}
\item{series}{a name of the time series.}
\item{method}{a Hurst exponent estimation method used.}
\item{call}{a matched call.}
}
\references{ 
[1] J. Geweke and S. Porter-Hudak (1983), The estimation and application of long-memory time series models,  \emph{J. Time Series Anal.} \bold{4}, 221--238.

[2] P.M. Robinson (1995), Log-periodogram regression of time series with long range dependence, \emph{Ann. of Statist.} \bold{23}, 1048--1072.

[3] C. Hurvich, R. Deo, and J. Brodsky (1998), The mean squared error of geweke and porter-hudak's estimator of the memory parameter of a long-memory time series, \emph{J. Time Series Anal.} \bold{19}, 19--46,  10.1111/1467-9892.00075.

[4] E.J. McCoy, A.T. Walden, and D.B. Percival (1998), Multitaper Spectral Estimation of Power Law Processes, \emph{IEEE Transactions on Signal Processing} \bold{46}, 655--668.
}
\seealso{\code{\link{pse}}, \code{\link{sdhee}}, \code{\link{ps.pgram}},
\code{\link{ps.mtm}}, \code{\link{ps.gspe}}}
\examples{
library(PowerSpectrum)
ps.gphe(ps.mtm(Donard_752_1992))
}
\keyword{ts}
