\name{ps.gspe}
\alias{ps.gspe}
\title{Gaussian Semiparametric Estimator}

\description{
Gaussian Semiparametric Estimator (GSPE) is a maximum likelihood fit of the time series power spectrum within a given frequency bandwidth. GSPE estimates the Hurst exponent and a scaling factor \eqn{b} by fitting the function  \eqn{f(\lambda)=b|\lambda|^{1-2H}} to a low-frequency part of the time series power spectrum by the maximum likelihood method. It was originally proposed in [1] and rigorously justified in [2].
}
\usage{
ps.gspe(x, L = 0, M = length(f), interval = c(0,1.5),
        verbose = TRUE, pse = NULL, ...)
}
\arguments{
\item{x}{an object of class \code{pse}, output from either \code{ps.pgram} or
\code{ps.mtm}.}
\item{L}{a number of the lowest Fourier frequences trimmed.}
\item{M}{a number of the highest Fourier frequency used.}
\item{interval}{an interval over which to estimate \eqn{H}.}
\item{verbose}{a logical flag. If TRUE (the default), prints information while executing.}
\item{pse}{the name of the pse object. Default: deparse(substitute(x)).}
\item{...}{}
}
\value{
An object of class \code{sdhee} with the following values set:
\item{H}{an estimate of the Hurst exponent.}
\item{asdH}{an asymptotic value of the standard deviation of the estimator of \code{H} based on the periodogram (see equation (7) on page 24 in [2] for GPHE and equation (4.1) on page 1640 in [1] for GSPE).}
\item{b}{an estimate of the scaling factor \eqn{b} from \eqn{f(\lambda)=b{\lambda}^{1-2H}}.}
\item{c}{\eqn{c=log(b)}.}
\item{L}{a number of the lowest Fourier frequences trimmed.}
\item{M}{a number of the highest Fourier frequency used.}
\item{psa}{a power spectrum approximation of the form \eqn{b{\lambda}^{1-2H}}.}
\item{series}{a name of the time series.}
\item{method}{a Hurst exponent estimation method used.}
\item{call}{a matched call.}
}
\references{ 
[1] R. Fox and M. Taqqu (1988), Large sample properties of parameter estimates for strongly dependent stationary gaussian time series, \emph{Ann. of  Statist.} \bold{17}, 1749--1766.

[2] P.M. Robinson (1995), Gaussian estimation of long range dependence, \emph{Ann. of Statist.} \bold{23}, 1630--1661.
}
\seealso{\code{\link{pse}}, \code{\link{sdhee}}, \code{\link{ps.pgram}}, \code{\link{ps.mtm}}, \code{\link{ps.gphe}}}
\examples{
library(PowerSpectrum)
ps.gspe(ps.mtm(AMO_1856_2008))
}
\keyword{ts}
