\name{ps.mtm}
\alias{ps.mtm}
\title{Multitaper Spectrum Estimator}

\description{
Multitaper is an average of several direct spectrum estimators, which use a set of orthogonal tapers (for details see [1-6]). The DPSS tapers can be used with the adaptive or simple uniform weighting [1,3,6]. The "sine" tapers are implemented only with the uniform weighting [4]. Confidence intervals are estimated using a jackknife method [2]. The output can be visualized using \code{plot} function which actually calls \code{plot.pse}.
}
\usage{
ps.mtm(x, dt = c("dpss", "sine"), wt = c("adapt", "uniform"),
       K = 3, cl = 0.95, verbose = TRUE, na.action = na.fail, 
       demean = TRUE, series = NULL, ...)
}
\arguments{

\item{x}{a vector containing a uniformly sampled real valued time series.}
\item{dt}{a data taper to be used. If equals to either "dpss" or "sine" then the appropriate taper will be created by a call to \code{dpss.taper} or \code{sine.taper} respectively. If of class \code{dpss.taper} or \code{sine.taper} or a matrix of size NxK where N is the input time series length and K is the number of tapers then \code{dt} will be used directly.}
\item{wt}{a weighting to use during spectrum estimation. If \code{dt} is a "sine" taper or a NxK matrix it will be forced to use uniform weighting. In case of the "dpss" taper the adaptive weighting (see [1,3,6]) can also be used.}
\item{K}{a number of tapers to be used.}
\item{cl}{a confidence level used for power spectrum confidence intervals estimation.}
\item{verbose}{a logical flag. If TRUE (the default), prints information while executing.}
\item{na.action}{function to be called to handle missing values.}
\item{demean}{a logical flag. If TRUE (the default), the mean value of \code{x}
is set to 0.}
\item{series}{a name for the series. Default: deparse(substitute(x)).}
\item{...}{Additional arguments passed to either \code{dpss.taper} or
\code{sine.taper}, the most useful of which is \code{K}, the number of data
tapers to use.}
}
\value{
An object of class \code{pse} with the following values set:
\item{frequency}{a vector of frequencies.}
\item{spectrum}{a power spectrum estimate.}
\item{spectrum.ci}{a jackknifed confidence interval for the power spectrum estimate.}
\item{cl}{a confidence level used for power spectrum confidence interval estimation.}
\item{ntaper}{a number of tapers used in the spectrum estimate.}
\item{taper}{The data taper used}
\item{weight}{The spectrum weighting used}
\item{series}{a name of the time series.}
\item{method}{a spectrum estimation method used.}
\item{call}{a matched call for \code{ps.mtm}.}
}
\references{ 
[1] D.J. Thomson (1982), Spectrum estimation and harmonic analysis. \emph{Proc. IEEE}, \bold{70}, 1055-1096.

[2] D.J. Thomson and A. D. Chave (1991), Jackknifed error estimates for spectra, coherences, and transfer functions, in \emph{Advances in Spectrum Analysis and Array Processing}, S. Haykin, Ed. Englewood Cliffs, NJ: Prentice-Hall, vol. 1, ch. 2, pp. 58-113.

[3] D. Percival and A. Walden (1993), \emph{Spectral Analysis for Physical Applications}, Cambridge University Press, 611 pp.

[4] K.S. Riedel and A. Sidorenko (1995), Minimum bias multiple taper spectral estimation, \emph{IEEE Transactions on Signal Processing}, \bold{43}, 188-195.

[5] E.J. McCoy, A.T. Walden, and D.B. Percival (1998), Multitaper Spectral Estimation of Power Law Processes, 
\emph{IEEE Transactions on Signal Processing, 46}, 655-668.

[6] D.J. Thomson, L.J. Lanzerotti, F.L. Vernon, M.R. Lessard, and L.T.P. Smith (2007), Solar Modal Structure of the Engineering Environment, \emph{Proc. IEEE}, \bold{95}, 1085-1132.
}
\seealso{\code{\link{pse}}, \code{\link{plot.pse}}, \code{\link{cs.mtm}}, \code{\link{ps.pgram}}}
\examples{
library(PowerSpectrum)
x = ps.mtm(Rarotonga_1726_1996)
plot(x)
}
\keyword{ts}
