\name{ps.pgram}
\alias{ps.pgram}
\title{Periodogram Spectrum Estimator}

\description{Periodogram is the simplest power spectrum estimator (for details see [1]). It estimates the power spectrum through the square of absolute value of discrete Fourier transform of the time series divided by the time series length.}
\usage{
ps.pgram(x, cl = 0.95, verbose = TRUE, na.action = na.fail, 
              demean = TRUE, series = NULL, ...)
}
\arguments{
\item{x}{a vector containing a uniformly sampled real valued time series.}
\item{cl}{a confidence level used for power spectrum confidence intervals estimation.}
\item{verbose}{a logical flag. If TRUE (the default), prints information while executing.}
\item{na.action}{a function to be called to handle missing values.}
\item{demean}{a logical flag. If TRUE (the default), the mean value of "x" is set to 0.}
\item{series}{a name for the time series.  Default: deparse(substitute(x)).}
\item{...}{}
}
\value{
An object of class \code{pse} with the following values set:
\item{frequency}{a vector of frequencies.}
\item{spectrum}{a power spectrum estimate.}
\item{spectrum.ci}{an asymptotic confidence interval for the power spectrum estimate.}
\item{cl}{a confidence level used for power spectrum confidence interval estimation.}
\item{ntaper}{a number of tapers used in the spectrum estimate.}
\item{series}{a name of the time series.}
\item{method}{a spectrum estimation method used.}
\item{call}{a matched call for \code{ps.pgram}.}
}
\references{ 
[1] D. Percival and A. Walden (1993), \emph{Spectral Analysis for Physical Applications}, Cambridge University Press, 611 pp.
}
\seealso{\code{\link{pse}}, \code{\link{ps.mtm}}, \code{\link{ps.gphe}},
\code{\link{ps.gspe}}}
\examples{
library(PowerSpectrum)
ps.pgram(AMO_1856_2008)
}
\keyword{ts}
