\name{sdf.test}
\alias{sdf.test}
\title{Spectral Goodness-of-Fit Test}

\description{This test compares a given estimate of the spectrum to the spectral density corresponding to a fitted model, AR1 or a power law, in the frequency range specified by the indices L and M. The null hypothesis is that the AR1 or the power law is a correct model for the given spectrum [1-2].  \code{sdf.test} outputs the spectral density of the fitted model, a test statistic and a p-value, which is the smallest significance level for which we would end up rejecting the null hypothesis.
}

\usage{
sdf.test(x, m, L = 0, M = length(x$frequency), verbose = TRUE)
}

\arguments{
\item{x}{an object of class \code{pse}. It could be generated by
\code{ps.pgram}.}
\item{m}{an object of class \code{sdhee} (generated by \code{ps.gphe} or
\code{ps.gspe}) or \code{sdare} (generated by \code{ps.ar1})}
\item{L}{a number of the lowest Fourier frequences trimmed.}
\item{M}{a number of the highest Fourier frequency used.}
\item{verbose}{a logical flag. If TRUE (the default), prints information while
executing.}
}

\value{
\item{T}{the test statistic.}
\item{p}{the test p-value.}
\item{model}{a character string specifying the fitted model.}
}
\references{ 
[1] J. Beran (1992),  A Goodness-of-Fit Test for Time Series with Long Range Dependence, \emph{J. R. Statis. Soc. B} \bold{54}, 749--760.

[2] D.B. Percival, J.E. Overland, and H.O. Mofjeld (2001), Interpretation of North Pacific Variability as a Short- and Long-Memory Process, \emph{J. Climate} \bold{14}, 4545--4559.
}
\seealso{\code{\link{pse}}, \code{\link{sdare}}, \code{\link{sdhee}},
\code{\link{pmt.test}}, \code{\link{ps.gphe}}, \code{\link{ps.gspe}}}
\examples{
library(PowerSpectrum)
pse = ps.pgram(Rarotonga_1726_1996)
sdare = ps.ar1(pse)
sdhee = ps.gspe(pse)
plot(pse, sdare, sdhee)
sdf.test(pse, m = sdare)
sdf.test(pse, m = sdhee)
}
\keyword{ts}
