\name{trend.test}
\alias{trend.test}
\title{Univariate time series linear trend estimation and detection}

\description{This function estimates a linear trend for a univariate time series using linear regression and then estimates its confidence intervals relatively to three competing hypothesis regarding residuals' autocorrelation structure: white noise, AR(1), power law. The function also estimates the number of data points (desired time series length) required to detect the observed trend for a given significance level and a test power under each hypothesis.}
\usage{
trend.test(x, ar = NULL,  h = NULL, a = 0.05, p = 0.5,
           verbose = TRUE, na.action = na.fail,
           demean = TRUE, series = NULL)
}
\arguments{
\item{x}{a vector containing a uniformly sampled real valued time series.}
\item{ar}{optional object of class \code{sdare}. It could be generated by
\code{ps.ar1}. Tests the trend of AR(1) model.}
\item{h}{optional object of class \code{sdhee}. It could be generated by
\code{ps.gphe} or \code{ps.gspe}. Tests the trend of Power Law model.}
\item{a}{significance level}
\item{p}{power of the test specified for calculation of a number of data points required to detect the observed trend}
\item{verbose}{a logical flag. If TRUE (the default), prints information while
executing.}
\item{na.action}{function to be called to handle missing values.}
\item{demean}{a logical flag. If TRUE (the default), the mean value of \code{x}
is set to 0.}
\item{series}{a name for the series. Default: deparse(substitute(x)).}
}
\value{
A list with the following elements:
\item{intercept}{an intercept estimate.}
\item{trend}{a slope estimate.}
\item{sd}{a standard deviation of the linear trend residuals.}
\item{trend.est}{a matrix of size 3x2 which first column contains estimated confidence intervals for the trend and the second column contains the number of data points required to detect the estimated trend for the given power. The rows correspond to different assumptions about trend residuals autocorrelation structure. Thus the first row corresponds to the case of white noise residuals, the second to AR1, and the last one to power law.}
\item{length}{the length of the time seires}
}
\note{All periodical signals have to be removed from the time series prior to \code{trend.test} application!}

\references{
[1] R.L. Smith (1993), Long-range dependence and global warming, In \emph{Statistics for the Environment} (V. Barnett and F. Turkman, eds.), John Wiley, Chichester, 141--161.

[2] D. Vyushin,  V. Fioletov, and T. Shepherd, (2007), Impact of long-range correlations on trend detection in total ozone, \emph{J.\ Geophys.\ Res.}  \bold{112}, 10.1029/2006JD008168,
\cr
\url{http://www.atmosp.physics.utoronto.ca/people/vyushin/Papers/Vyushin_Fioletov_Shepherd_Trend_Detection_in_Total_Ozone.pdf}.
}
\seealso{\code{\link{sdare}}, \code{\link{sdhee}}, \code{\link{ps.pgram}}, \code{\link{ps.mtm}}, \code{\link{ps.gphe}}, \code{\link{ps.gspe}}}
\examples{
library(PowerSpectrum)
NAO = NAO_DJFM_Hurrell_1864_2008[seq((1946-1864+1),(1995-1864+1))]
plot(seq(1946,1995), NAO, type="o", xlab="")
NAOres = lm(NAO ~ seq(1,length(NAO)))$residuals
pse = ps.pgram(NAOres)
sdare = ps.ar1(pse)
sdhee = ps.gspe(pse)
tr = trend.test(NAO, ar=sdare, h=sdhee)
}
\keyword{ts}
