/* This program applies DFA(1-5) analysis on the data (non-overlapping indows).
   For each indow F(n)-fluctuation function is calculated around the local
   trend which chosen to be N-polynomial according to parameter "degree"==N.
   The output is F(n) vs n-window size.
*/ 

#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <errno.h>

#define N_MAX 6
#define RelativeMaxScale 1
#define ScaleDensity 6 /* increase this to increase the density */

double sumy, sumxy, sumx2y, sumx3y, sumx4y, sumx5y;
//double np[0], np[1], np[2], np[3], np[4], np[5], np[6], np[7], np[8], np[0]0;

double Mat[N_MAX][N_MAX], Vec[N_MAX], coeff[N_MAX], np[2*N_MAX-2];

void MyPower(int n, int order)
{
  int i;
  double x;
  x = (double) n;

 for (i=0; i < 2*order; i++) np[i] = pow(x, i+1);
/*
  switch (order) {

    case 5:
       np[8] = pow(x,9.0);
       np[9] = pow(x,10.0);

    case 4:
       np[6] = pow(x,7.0);
       np[7] = pow(x,8.0);

    case 3:
       np[4] = pow(x,5.0);
       np[5] = pow(x,6.0);

    case 2:
       np[2] = pow(x,3.0);
       np[3] = pow(x,4.0);

    case 1:
       np[0] = x;
       np[1] = pow(x,2.0);
  }
*/
} 

void Summation(int order, double X, double Y)
{
  switch (order) {             
    case 5:
       sumx5y += pow(X,5.0)*Y;
    case 4:
       sumx4y += pow(X,4.0)*Y;    
    case 3:
       sumx3y += pow(X,3.0)*Y;    
    case 2:
       sumx2y += pow(X,2.0)*Y;    
    case 1:
       sumxy += X*Y;
       sumy += Y;
  }
} 

void GetCoeff(int order)
{
  int j, k;
  double p1, p2, p3;

  for (k=0; k <= N_MAX-1; k++) {
    coeff[k] = 0.0;
    Vec[k] = 0.0;
    for (j=0; j<= N_MAX-1; j++) Mat[k][j] = 0.0;
  }

  switch (order) {

    case 5:
      Vec[0]=sumy;      		         		     		    
      Vec[1]=sumxy;
      Vec[2]=sumx2y;
      Vec[3]=sumx3y;
      Vec[4]=sumx4y;
      Vec[5]=sumx5y;
      p1 = np[0]*(np[4]-15*np[3]+85*np[2]-225*np[1]+274*np[0]-120);
      p2 = np[0]*(np[9]-55*np[7]+1023*np[5]-7645*np[3]+21076*np[1]-14400);
      p3 = np[0]*(np[8]-np[7]-54*np[6]+54*np[5]+969*np[4]-969*np[3]-6676*np[2]+6676*np[1]+14400*np[0]-14400);
      Mat[0][0] = 6*(6*np[4]+15*np[3]+160*np[2]+225*np[1]+314*np[0]+120)/p1;
      Mat[0][1] = Mat[1][0] = -126*(5*np[3]+10*np[2]+55*np[1]+50*np[0]+28)/p1;
      Mat[0][2] = Mat[2][0] = 420*(8*np[2]+12*np[1]+34*np[0]+15)/p1;
      Mat[0][3] = Mat[3][0] = -1260*(6*np[1]+6*np[0]+7)/p1;
      Mat[0][4] = Mat[4][0] = 3780*(2*np[0]+1)/p1;
      Mat[0][5] = Mat[5][0] = -2772/p1;
      Mat[1][1] = 588*(25*np[7]+300*np[6]+1650*np[5]+5700*np[4]+14085*np[3]+23520*np[2]+23360*np[1]+12600*np[0]+3288)/p2;
      Mat[1][2] = Mat[2][1] = -8820*(10*np[5]+90*np[4]+365*np[3]+860*np[2]+1359*np[1]+1252*np[0]+420)/p3;
      Mat[1][3] = Mat[3][1] = 17640*(12*np[5]+105*np[4]+420*np[3]+900*np[2]+1100*np[1]+777*np[0]+274)/p2;
      Mat[1][4] = Mat[4][1] = -8820*(25*np[3]+170*np[2]+545*np[1]+700*np[0]+252)/p3;
      Mat[1][5] = Mat[5][1] = 5544*(15*np[3]+105*np[2]+365*np[1]+525*np[0]+274)/p2;
      Mat[2][2] = 17640*(32*np[5]+240*np[4]+800*np[3]+1560*np[2]+2058*np[1]+1575*np[0]+425)/p2;
      Mat[2][3] = Mat[3][2] = -88200*(16*np[3]+80*np[2]+170*np[1]+178*np[0]+105)/p3;
      Mat[2][4] = Mat[4][2] = 12600*(120*np[3]+588*np[2]+1282*np[1]+1239*np[0]+365)/p2;
      Mat[2][5] = Mat[5][2] = -582120*(np[1]+3*np[0]+5)/p3;
      Mat[3][3] = 75600*(48*np[3]+210*np[2]+356*np[1]+294*np[0]+139)/p2;
      Mat[3][4] = Mat[4][3] = -793800*(5*np[1]+11*np[0]+7)/p3;
      Mat[3][5] = Mat[5][3] = 388080*(4*np[1]+9*np[0]+8)/p2;
      Mat[4][4] = Mat[4][4] = 88200*(50*np[1]+99*np[0]+37)/p2;
      Mat[4][5] = Mat[5][4] = -1746360/p3;
      Mat[5][5] = 698544/p2;
      break;

    case 4:
      Vec[0]=sumy;      		         		     		    
      Vec[1]=sumxy;
      Vec[2]=sumx2y;
      Vec[3]=sumx3y;
      Vec[4]=sumx4y;
      p1 = np[0]*(np[3]-10*np[2]+35*np[1]-50*np[0]+24);
      p2 = np[0]*(np[7]-30*np[5]+273*np[3]-820*np[1]+576);
      p3 = np[0]*(np[6]-np[5]-29*np[4]+29*np[3]+244*np[2]-244*np[1]-576*np[0]+576);
      Mat[0][0] = 5*(5*np[3]+10*np[2]+55*np[1]+50*np[0]+24)/p1;
      Mat[0][1] = Mat[1][0] = -50*(6*np[2]+9*np[1]+23*np[0]+10)/p1;
      Mat[0][2] = Mat[2][0] = 1050*(np[1]+np[0]+1)/p1;
      Mat[0][3] = Mat[3][0] = -700*(2*np[0]+1)/p1;
      Mat[0][4] = Mat[4][0] = 630/p1;
      Mat[1][1] = 100*(48*np[5]+378*np[4]+1233*np[3]+2310*np[2]+2899*np[1]+2100*np[0]+548)/p2;
      Mat[1][2] = Mat[2][1] = -2100*(9*np[3]+48*np[2]+97*np[1]+93*np[0]+50)/p3;
      Mat[1][3] = Mat[3][1] = 280*(96*np[3]+510*np[2]+1085*np[1]+975*np[0]+274)/p2;
      Mat[1][4] = Mat[4][1] = -6300*(2*np[1]+7*np[0]+10)/p3;
      Mat[2][2] = 8820*(9*np[3]+40*np[2]+65*np[1]+50*np[0]+21)/p2;
      Mat[2][3] = Mat[3][2] = -29400*(4*np[1]+9*np[0]+5)/p3;
      Mat[2][4] = Mat[4][2] = 6300*(9*np[1]+21*np[0]+17)/p2;
      Mat[3][3] = 2800*(64*np[1]+126*np[0]+47)/p2;
      Mat[3][4] = Mat[4][3] = -88200/p3;
      Mat[4][4] = 44100/p2;
      break;

    case 3:
      Vec[0]=sumy;      		         		     		    
      Vec[1]=sumxy;
      Vec[2]=sumx2y;
      Vec[3]=sumx3y;
      p1 = np[0]*(np[2]-6*np[1]+11*np[0]-6);
      p2 = np[0]*(np[5]-14*np[3]+49*np[1]-36);
      p3 = np[0]*(np[4]-np[3]-13*np[2]+13*np[1]+36*np[0]-36);
      Mat[0][0] = 8*(2*np[2]+3*np[1]+7*np[0]+3)/p1;
      Mat[0][1] = Mat[1][0] = -20*(6*np[1]+6*np[0]+5)/p1;
      Mat[0][2] = Mat[2][0] = 120*(2*np[0]+1)/p1;
      Mat[0][3] = Mat[3][0] = -140/p1;
      Mat[1][1] = 200*(6*np[3]+27*np[2]+42*np[1]+30*np[0]+11)/p2;
      Mat[1][2] = Mat[2][1] = -300*(9*np[1]+21*np[0]+10)/p3;
      Mat[1][3] = Mat[3][1] = 280*(6*np[1]+15*np[0]+11)/p2;
      Mat[2][2] = 360*(18*np[1]+35*np[0]+13)/p2;
      Mat[2][3] = Mat[3][2] = -4200/p3;
      Mat[3][3] = 2800/p2;
      break;

    case 2:
      Vec[0]=sumy;      		         		     		    
      Vec[1]=sumxy;
      Vec[2]=sumx2y;
      Mat[0][0] = 3*(3*np[1]+3*np[0]+2)/np[0]/(np[1]-3*np[0]+2);
      Mat[0][1] = Mat[1][0] = -18*(2*np[0]+1)/np[0]/(np[1]-3*np[0]+2);
      Mat[0][2] = Mat[2][0] = 30/np[0]/(np[1]-3*np[0]+2);
      Mat[1][1] = 12*(16*np[1]+30*np[0]+11)/np[0]/(np[3]-5*np[1]+4);
      Mat[1][2] = Mat[2][1] = -180.0/np[0]/(np[2]-np[1]-4*np[0]+4);
      Mat[2][2] = 180/np[0]/(np[3]-5*np[1]+4);
      break;

    case 1:
      Vec[0]=sumy;      		         		     		    
      Vec[1]=sumxy;
      Mat[0][0] = 2*(2*np[0]+1)/np[0]/(np[0]-1);      
      Mat[0][1] = Mat[1][0]=-6/np[0]/(np[0]-1);      
      Mat[1][1] = 12/np[0]/(np[1]-1);      
  }

  for (k=0; k <= order; k++)
    for (j=0; j<= order; j++) coeff[k] += Mat[k][j]*Vec[j];
}

int NextScale(int n, double LSF)
{
   int iTWS;
   double TempScale;

   TempScale = LSF*n;
   while ( (int) (TempScale) <  (n + 1.0)) TempScale *= LSF; 
   iTWS = (int) (TempScale);
   return(iTWS);
}

void dfa(int *degree, int *NumberPoints, double *DATA, int *MinScale, int *Scales, double *F)
{

int NumberWindows, MaxScale;
int i, j, Index, Scale;

double X, Y, Ymin, temp, Fl, Fluctuations, LogScaleFactor;

  /* this scale factor is used to evenly space the ouput on a log scale */
  LogScaleFactor = pow(2.0, 1.0/ScaleDensity);

  for(i=1; i < *NumberPoints; i++) DATA[i] += DATA[i-1];

/*  MinScale = *degree+2; */
  MaxScale = (int) (*NumberPoints*RelativeMaxScale);
  Index = 0;

  for (Scale = *MinScale; Scale <= MaxScale; Index++) {

//    fprintf(stderr, "Index = %d, Scale = %d\n", Index, Scale);
    Fluctuations = 0.0;
    NumberWindows = (int) (*NumberPoints/Scale);
    MyPower(Scale, *degree);

    /* from the left side to the right */
    for (i=0; i < NumberWindows; i++){

      sumy=sumxy=sumx2y=sumx3y=sumx4y=sumx5y=0.0;
      Ymin = DATA[i*Scale];
      for (j=0; j < Scale; j++){   
	X = (double) j+1;        
        Y = DATA[i*Scale+j] - Ymin;
        Summation(*degree, X, Y);
      }

      GetCoeff(*degree);

      Fl = 0.0; 
      for (j=0; j < Scale; j++){
        X = (double) j+1;        
        Y = DATA[i*Scale+j] - Ymin;
	temp = coeff[5]*pow(X,5.0)+coeff[4]*pow(X,4.0)+coeff[3]*pow(X,3.0)+coeff[2]*X*X+coeff[1]*X+coeff[0]-Y;
	Fl += temp*temp;
      }
      Fluctuations += Fl /(Scale-1);
    }

//    fprintf(stderr, "Part 1 is done.\n");

    /* from the right side to the left */
    for (i=0; i < NumberWindows; i++){

      sumy=sumxy=sumx2y=sumx3y=sumx4y=sumx5y=0.0;
      Ymin = DATA[*NumberPoints-1-i*Scale];
      for (j=0; j < Scale; j++){   
	X = Scale-j;        
        Y = DATA[*NumberPoints-1-i*Scale-j] - Ymin;
        Summation(*degree, X, Y);
      }

      GetCoeff(*degree);	           

      Fl = 0.0; 
      for (j=0; j < Scale; j++){
        X = Scale-j;        
        Y = DATA[*NumberPoints-1-i*Scale-j] - Ymin;
	temp = coeff[5]*pow(X,5.0)+coeff[4]*pow(X,4.0)+coeff[3]*pow(X,3.0)+coeff[2]*X*X+coeff[1]*X+coeff[0]-Y;
	Fl += temp*temp;
      }
       Fluctuations += Fl /(Scale-1);
    }

//    fprintf(stderr, "Part 2 is done.\n");

    Scales[Index] = Scale;
    F[Index] = sqrt(Fluctuations/2.0/NumberWindows);

    Scale = NextScale(Scale, LogScaleFactor);

//    fprintf(stderr, "Part 3 is done.\n");
  }  // for (Scale = MinScale; Scale <= MaxScale;)
} 
